from dg_sdk.core.rsa_utils import rsa_design, rsa_long_encrypt
from dg_sdk.request_tools import request_post
from dg_sdk.dg_client import DGClient
from Crypto.Hash import MD5
from dg_sdk.core.api_request import verify_sign


class DGTools(object):

    @classmethod
    def verify_sign(cls, data, sign, pub_key=""):
        """
        校验返回报文签名
        :param data: 返回data
        :param sign:  返回签名
        :param pub_key: 公钥，默认使用SDK初始化时的公钥
        :return: 是否通过校验
        """
        if not pub_key:
            pub_key = DGClient.mer_config.public_key
        return verify_sign(sign, data, pub_key)

    @classmethod
    def verify_webhook_sign(cls, data, sign, key):
        """
        校验webhook 返回报文签名
        :param data: 返回data
        :param sign:  返回签名
        :param key: 加签key
        :return: 是否通过校验
        """
        h = MD5.new()
        h.update(str(data + key).encode('utf-8'))
        return h.hexdigest().lower() == sign.lower()


    @classmethod
    def encrypt_with_public_key(cls, orignal_str, public_key=""):
        """
        通过RSA 公钥加密敏感信息
        :param orignal_str: 原始字符串
        :param public_key: 公钥，不传使用商户配置公钥
        :return: 密文
        """
        if not public_key:
            public_key = DGClient.mer_config.public_key
        return rsa_long_encrypt(orignal_str, public_key)

    @classmethod
    def request_post(cls, url, request_params, files=None):
        """
        网络请求通用方法，根据请求的URL 地址判断是V1还是V2版本接口
        :param url: 请求地址
        :param request_params: 请求参数
        :param files: 附带文件，可为空
        :return: 网络请求返回内容
        """
        required_params = {
        }
        required_params.update(request_params)
        return request_post(url=url, request_params=required_params, files=files)





# 支付宝间连证书上传
add_cert_url = "/v2/pcredit/certificate/config"
# 创建花呗分期商家贴息方案
create_solution = "/v2/pcredit/solution/create"
# 上架/下架花呗分期贴息
modify_solution_status = "/v2/pcredit/statue/modify"
# 更新花呗分期商家贴息方案
modify_solution = "/v2/pcredit/solution/modify"
# 查询花呗分期贴息
query_solution = "/v2/pcredit/order/query"
# 花呗活动详情查询
query_act_detail = "/v2/pcredit/solution/query"



import json


def replace_none_to_empty(params_dict):
    """
    替换字典中为none值的key 改为空字符串
    :param params_dict:
    :return: 更新后的 dict
    """
    temp_dict = dict()
    temp_dict.update(params_dict)
    for (key, value) in params_dict.items():

        if value is None or value == {} or value == []:
            temp_dict[key] = ""

    return temp_dict


def pop_empty_value(params_dict):
    """
    去掉参数中value为空的字段
    :return: 去除空参数后的参数字典
    """
    temp_dict = dict()
    temp_dict.update(params_dict)
    for (key, value) in params_dict.items():
        # 这里列出来写，不要直接用 if value 作为判断结果
        if value is None or value == '' or value == {} or value == []:
            temp_dict.pop(key)
    return temp_dict


def get_plain_text(all_params):
    # 组装原始签名参数按照 key 的 ASCII 升序组装
    temp_list = list()
    for (k, v) in sorted(all_params.items()):
        if not isinstance(v, str):
            v = json.dumps(v, ensure_ascii=False)
        temp_list.append('{}={}'.format(str(k), str(v)))
    plain_text = '&'.join(temp_list)
    return plain_text


def read_file(file_path):
    with open(file_path, 'r') as f:
        return f.read()


def sort_dict(params):
    """
    排序json 对象，按ASCII顺序排序。多层结构只排序第一层
    :param params:
    :return:
    """
    keys = sorted(params.keys())
    result = {}
    for key in keys:
        value = params.get(key)
        if type(value).__name__ == 'dict':
            result[key] = value
        elif type(value).__name__ == 'list' and len(value) != 0:
            result[key] = params.get(key)
        elif params.get(key) is not None:
            result[key] = params.get(key)
    return result




from dg_sdk.request_tools import request_post
from dg_sdk.pay.pay_api_urls import bank_credit_payment_apply, bank_credit_payment_confirm, bank_credit_query, \
    bank_credit_refund, bank_credit_sign

from dg_sdk.core.rsa_utils import rsa_long_encrypt
from dg_sdk.dg_client import DGClient
from dg_sdk.pay.module.credit_card_info import CreditCardInfo


class Installment(object):
    """
    银行卡分期支付相关接口
    银行卡分期支付签约，
    一段式分期支付
    二段式分期支付申请
    二段式分期支付确认
    银行卡分期退款
    银行卡分期查询
    """

    @classmethod
    def sign(cls, trans_amt, front_url, credit_card: CreditCardInfo, request_type, **kwargs):
        """
        银行卡分期支付签约

        https://paas.huifu.com/partners/api/#/hfq/api_hfq_yhkfqqy
        :param trans_amt: 交易金额
        :param front_url: 页面跳转地址
        :param credit_card: 卡片信息
        :param request_type: 请求类型，0:pc 1:安卓 2：ios
        :param kwargs: 非必填额外参数
        :return: 返回报文
        """

        required_params = {
            "trans_amt": trans_amt,
            "bank_card_mobile_no": credit_card.bank_card_mobile_no,
            "bank_card_no": credit_card.bank_card_no,
            "card_name": credit_card.card_name,
            "certificate_no": credit_card.certificate_no,
            "certificate_type": credit_card.certificate_type,
            "bank_no": credit_card.bank_no,
            "card_act_type": credit_card.card_act_type,
            "card_type": credit_card.card_type,
            "cvv2": credit_card.cvv2,
            "valid_date": credit_card.valid_date,
            "request_type": request_type,
            "front_url": front_url
        }

        required_params.update(kwargs)

        return request_post(bank_credit_sign, required_params)

    @classmethod
    def payment_apply(cls, trans_amt, credit_card: CreditCardInfo, goods_desc, instalments_num,
                      notify_url, terminal_device_data, risk_check_data, extend_pay_data, **kwargs):
        """
        二段式分期支付申请

        https://paas.huifu.com/partners/api/#/hfq/api_hfq_yhkfqzfqq
        :param trans_amt: 交易金额
        :param credit_card: 卡片信息
        :param goods_desc: 商品描述
        :param instalments_num: 银行卡分期期数
        :param notify_url: 异步通知地址
        :param terminal_device_data: 设备信息数据
        :param risk_check_data: 风控信息
        :param extend_pay_data: 网联扩展数据
        :param kwargs: 非必填额外参数
        """
        required_params = {
            "trans_amt": trans_amt,
            "goods_desc": goods_desc,
            "instalments_num": instalments_num,
            "mobile_no": credit_card.bank_card_mobile_no,
            "bank_card_no": credit_card.bank_card_no,
            "certificate_name": credit_card.card_name,
            "certificate_no": credit_card.certificate_no,
            "certificate_type": credit_card.certificate_type,
            "bank_no": credit_card.bank_no,
            "card_act_type": credit_card.card_act_type,
            "card_type": credit_card.card_type,
            "cvv2": credit_card.cvv2,
            "valid_date": credit_card.valid_date,
            "risk_check_data": risk_check_data,
            "notify_url": notify_url,
            "extend_pay_data": extend_pay_data,
            "terminal_device_data": terminal_device_data
        }

        required_params.update(kwargs)
        return request_post(bank_credit_payment_apply, required_params)

    @classmethod
    def payment_confirm(cls, goods_desc, cvv2, org_req_date, org_req_seq_id, valid_date, verify_code, **kwargs):
        """
        二段式分期支付确认
        :param goods_desc: 商品描述
        :param cvv2: 信用卡cvv2
        :param org_req_date: 原请求时间
        :param org_req_seq_id: 原请求流水号
        :param valid_date: 信用卡有效期
        :param verify_code: 手机验证码
        :param kwargs: 非必填额外参数
        :return: 返回报文
        """

        required_params = {
            "goods_desc": goods_desc,
            "cvv2": rsa_long_encrypt(cvv2, DGClient.mer_config.public_key),
            "org_req_date": org_req_date,
            "org_req_seq_id": org_req_seq_id,
            "valid_date": rsa_long_encrypt(valid_date, DGClient.mer_config.public_key),
            "verify_code": verify_code
        }
        required_params.update(kwargs)
        return request_post(bank_credit_payment_confirm, required_params)

    # @classmethod
    # def payment(cls, trans_amt, credit_card: CreditCardInfo, instalments_num, notify_url, **kwargs):
    #     """
    #     银行卡分期支付确认
    #     :param credit_card: 卡片信息
    #     :param trans_amt: 交易金额
    #     :param instalments_num: 分期期数
    #     :param notify_url: 异步通知地址
    #     :param kwargs: 非必填额外参数
    #     :return: 返回报文
    #     """
    #
    #     required_params = {
    #         "trans_amt": trans_amt,
    #         "instalments_num": instalments_num,
    #         "bank_card_mobile_no": credit_card.bank_card_mobile_no,
    #         "bank_card_no": credit_card.bank_card_no,
    #         "card_name": credit_card.card_name,
    #         "certificate_no": credit_card.certificate_no,
    #         "certificate_type": credit_card.certificate_type,
    #         "bank_no": credit_card.bank_no,
    #         "card_act_type": credit_card.card_act_type,
    #         "card_type": credit_card.card_type,
    #         "cvv2": credit_card.cvv2,
    #         "valid_date": credit_card.valid_date,
    #         "notify_url": notify_url,
    #     }
    #     required_params.update(kwargs)
    #     return request_post(bank_credit_payment, required_params)

    @classmethod
    def query(cls, org_req_date, org_req_seq_id, org_hf_seq_id="", **kwargs):
        """
        分期支付查询
        :param org_req_seq_id: 原始请求流水号
        :param org_req_date: 原始订单请求时间
        :param org_hf_seq_id: 交易返回的全局流水号
        :param kwargs: 非必填额外参数
        :return: 返回报文
        """

        required_params = {
            "org_req_date": org_req_date,
            "org_req_seq_id": org_req_seq_id,
            "org_hf_seq_id": org_hf_seq_id,
        }
        required_params.update(kwargs)
        return request_post(bank_credit_query, required_params, need_seq_id=False)

    @classmethod
    def refund(cls, ord_amt, terminal_device_data, risk_check_data, notify_url, org_req_date, org_req_seq_id,
               org_hf_seq_id="", **kwargs):
        """
        退款

        https://paas.huifu.com/partners/api/#/smzf/api_qrpay_tk
        :param ord_amt: 金额
        :param terminal_device_data: 设备信息
        :param risk_check_data: 安全信息
        :param notify_url: 异步通知地址
        :param org_req_seq_id: 原始请求流水号
        :param org_req_date: 原始订单请求时间
        :param org_hf_seq_id: 交易返回的全局流水号
        :param kwargs: 非必填额外参数
        :return: 返回报文
        """

        required_params = {
            "ord_amt": ord_amt,
            "terminal_device_data": terminal_device_data,
            "risk_check_data": risk_check_data,
            "notify_url": notify_url,
            "org_req_date": org_req_date,
            "org_req_seq_id": org_req_seq_id,
            "org_hf_seq_id": org_hf_seq_id,
        }
        required_params.update(kwargs)
        return request_post(bank_credit_refund, required_params)



# ---------- 聚合正扫----------
scan_payment_create = '/v2/trade/payment/jspay'  # 聚合正扫
scan_payment_close = '/v2/trade/payment/scanpay/close'  # 交易关单
scan_payment_close_query = '/v2/trade/payment/scanpay/closequery'  # 交易关单查询
scan_payment_query = '/v2/trade/payment/scanpay/query'  # 交易查询
scan_payment_refund = '/v2/trade/payment/scanpay/refund'  # 交易退款
scan_payment_refund_query = '/v2/trade/payment/scanpay/refundquery'  # 退款查询

payment_confirm = "/v2/trade/payment/delaytrans/confirm"  # 交易确认
payment_confirm_query = "/v2/trade/payment/delaytrans/confirmquery"  # 交易确认查询
payment_confirm_refund = "/v2/trade/payment/delaytrans/confirmrefund"  # 交易确认退款


split_list = '/v2/trade/trans/split/query'

withhold_pay = "/v2/trade/onlinepayment/withholdpay"  # 代扣

customer_reg = "/v2/merchant/customer/add"  # 快捷支付用户注册

# ---------- 反扫----------
offline_payment_scan = '/v2/trade/payment/micropay'  # 聚合反扫
union_user_id = '/v2/trade/payment/usermark/query'  # 获取银联用户标识

# ---------------快捷支付-------------------

card_payment_page_pay = '/v2/trade/onlinepayment/quickpay/pageinfo'  # 快捷支付页面版
card_bind_apply = '/v2/quickbuckle/apply'  # 快捷绑卡申请
card_bind_confirm = '/v2/quickbuckle/confirm'  # 快捷绑卡确认
card_un_bind = '/v2/quickbuckle/unbind'  # 快捷卡解绑

card_payment_apply = '/v2/trade/onlinepayment/quickpay/apply'  # 快捷支付申请
card_payment_confirm = '/v2/trade/onlinepayment/quickpay/confirm'  # 快捷支付确认

# ---------------线上交易-------------------
union_app_pay = '/v2/trade/onlinepayment/unionpay'  # 银联APP 支付
wap_pay = '/v2/trade/onlinepayment/wappay'  # 手机网页支付
web_page = '/v2/trade/onlinepayment/bankpay/pageinfo'  # 网银支付

online_payment_query = '/v2/trade/onlinepayment/query'  # 查询
online_payment_refund = '/v2/trade/onlinepayment/refund'  # 退款
online_payment_refund_query = '/v2/trade/onlinepayment/refund/query'  # 退款查询

# 网银付款银行账户查询接口
bank_pay_payer_query = '/v2/trade/onlinepayment/bankpay/payerquery'
# 网银支付银行列表查询接口
bank_pay_bank_list = '/v2/trade/onlinepayment/bankpay/banklist'

# ------------------余额支付----------------
account_payment_create = '/v2/trade/acctpayment/pay'  # 余额支付创建
account_payment_query = '/v2/trade/acctpayment/pay/query'  # 余额支付查询
account_payment_refund = '/v2/trade/acctpayment/refund'  # 余额支付退款
account_payment_query_refund = '/v2/trade/acctpayment/refund/query'  # 余额支付退款查询
account_balance_query = '/v2/trade/acctpayment/balance/query'  # 余额信息查询

# ------------------取现--------------------

drawcash_create = '/v2/trade/settlement/enchashment'  # 创建取现
drawcash_query = '/v2/trade/settlement/query'  # 出金交易查询

# ------------------代发--------------------

surrogate_create = '/v2/trade/settlement/surrogate'  # 创建代发

# ------------------银行卡分期支付--------------------

bank_credit_sign = '/v2/trade/installment/bccredit/sign'  # 银行卡分期支付签约
bank_credit_payment = '/v2/trade/installment/bccredit/pay'  # 一段式分期支付
bank_credit_payment_apply = '/v2/trade/installment/bccredit/apply'  # 二段式分期支付申请
bank_credit_payment_confirm = '/v2/trade/installment/bccredit/confirm'  # 二段式分期支付确认
bank_credit_refund = '/v2/trade/installment/bccredit/refund'  # 银行卡分期退款
bank_credit_query = '/v2/trade/installment/bccredit/query'  # 银行卡分期查询

# ------------------银行卡刷卡交易--------------------
card_trade_query = '/v2/trade/card/query'  # 银行卡交易查询
card_payment_sms = '/ssproxy/quickSendSms'  # 短信重发

payment_confirm_list = "/topqur/payConfirmListQuery"  # 交易确认列表查询


from dg_sdk.request_tools import request_post
from dg_sdk.pay.pay_api_urls import account_payment_create, \
    account_payment_query, account_payment_query_refund, account_payment_refund, account_balance_query


class AcctPayment(object):
    """
    余额支付相关接口，绑卡，支付，退款，交易查询等
    """

    @classmethod
    def create(cls, ord_amt, acct_split_bunch, risk_check_data, out_huifu_id, **kwargs):
        """
        余额支付订单
        https://paas.huifu.com/partners/api/#/yuer/api_acctpayzf
        :param ord_amt: 交易金额，单位为元，（例如：100.00）
        :param acct_split_bunch: 分账对象，
        :param risk_check_data: 安全信息，
        :param out_huifu_id: 出款方商户号
        :param kwargs:  非必填额外参数
        :return: 支付对象
        """

        required_params = {
            "ord_amt": ord_amt,
            "acct_split_bunch": acct_split_bunch,
            "risk_check_data": risk_check_data,
            "out_huifu_id": out_huifu_id
        }
        required_params.update(kwargs)
        return request_post(account_payment_create, required_params)

    @classmethod
    def query(cls, org_req_date, org_req_seq_id="", org_hf_seq_id="", **kwargs):
        """
        余额支付查询
        https://paas.huifu.com/partners/api/#/yuer/api_acctpaycx
        :param org_req_date: 原始订单请求时间
        :param org_hf_seq_id: 交易返回的全局流水号
        :param org_req_seq_id: 原始请求流水号
        :param kwargs: 非必填额外参数
        :return: 支付对象
        """

        required_params = {
            "org_req_date": org_req_date,
            "org_req_seq_id": org_req_seq_id,
            "org_hf_seq_id": org_hf_seq_id,
        }

        required_params.update(kwargs)
        return request_post(account_payment_query, required_params, need_seq_id=False)

    @classmethod
    def refund(cls, ord_amt, org_req_date, org_req_seq_id="", org_hf_seq_id="", **kwargs):
        """
        余额支付退款
        https://paas.huifu.com/partners/api/#/yuer/api_acctpaytk
        :param ord_amt: 退款金额
        :param org_req_seq_id: 原始请求流水号
        :param org_req_date: 原始订单请求时间
        :param org_hf_seq_id: 交易返回的全局流水号
        :param kwargs: 非必填额外参数
        """
        required_params = {
            "ord_amt": ord_amt,
            "org_req_date": org_req_date,
            "org_req_seq_id": org_req_seq_id,
            "org_hf_seq_id": org_hf_seq_id
        }
        required_params.update(kwargs)
        return request_post(account_payment_refund, required_params)

    @classmethod
    def refund_query(cls, org_req_date, org_req_seq_id, **kwargs):
        """
        余额支付退款查询
        https://paas.huifu.com/partners/api/#/yuer/api_acctpaytkcx
        :param org_req_seq_id: 原始请求流水号
        :param org_req_date: 原始退款请求时间
        :param kwargs: 非必填额外参数
        :return: 退款对象
        """
        required_params = {
            "org_req_date": org_req_date,
            "org_req_seq_id": org_req_seq_id,
        }
        required_params.update(kwargs)
        return request_post(account_payment_query_refund, required_params, need_seq_id=False)

    @classmethod
    def balance_query(cls, **kwargs):
        """
        余额信息查询
        https://paas.huifu.com/partners/api/#/jyjs/api_jyjs_yuexxcx
        :param kwargs: 非必填额外参数
        :return: 余额信息查询返回报文
        """
        return request_post(account_balance_query, kwargs)



from dg_sdk.request_tools import request_post
from dg_sdk.merchant.huabei_api_urls import *
from dg_sdk.dg_client import DGClient
from typing import List
from dg_sdk.merchant.module.file_info import FileInfo
import json


class Huabei(object):

    @classmethod
    def add_ali_cert_info(cls, app_id, file_list: List[FileInfo], **kwargs):
        """
        支付宝间连证书上传

        https://paas.huifu.com/partners/api/#/hfq/api_hfq_hbjlzssc
        :param app_id: 支付宝：开发者应用ID，微信：服务商的APPID
        :param file_list: 证书文件列表
        :param kwargs: 非必填额外参数
        :return:
        """

        file_info_list = []
        if file_list:
            for file in file_list:
                file_info_list.append(file.obj_to_dict())

        required_params = {
            "product_id": DGClient.mer_config.product_id,
            "app_id": app_id,
            "file_list": json.dumps(file_info_list)
        }

        required_params.update(kwargs)
        return request_post(add_cert_url, required_params)

    @classmethod
    def create_pcredit_solution(cls, activity_name, start_time, end_time, min_money_limit, max_money_limit,
                                amount_budget, install_num_str_list, budget_warning_money, budget_warning_mail_list,
                                budget_warning_mobile_no_list, **kwargs):
        """
        创建花呗分期商家贴息方案

        https://paas.huifu.com/partners/api/#/hfq/api_hfq_cjhbfa
        :param activity_name: 花呗分期商家贴息活动名称
        :param start_time: 活动开始时间示例值:2019-07-08 00:00:00
        :param end_time: 活动结束时间，必须大于start_time，且结束时间必须晚于当前时间示例值: 2029-07-10 00:00:00
        :param min_money_limit: 免息金额下限
        :param max_money_limit: 免息金额上限
        :param amount_budget: 花呗分期贴息预算金额
        :param install_num_str_list: 花呗分期数集合，不同期数之间用逗号分开示例值:[“3”,”6”,”12”,”24”]
        :param budget_warning_money: 预算提醒金额
        :param budget_warning_mail_list:预算提醒邮件列表
        :param budget_warning_mobile_no_list: 预算提醒手机号列表
        :param kwargs: 非必填额外参数
        :return:
        """

        required_params = {
            "product_id": DGClient.mer_config.product_id,
            "activity_name": activity_name,
            "start_time": start_time,
            "end_time": end_time,
            "min_money_limit": min_money_limit,
            "max_money_limit": max_money_limit,
            "amount_budget": amount_budget,
            "install_num_str_list": install_num_str_list,
            "budget_warning_money": budget_warning_money,
            "budget_warning_mail_list": budget_warning_mail_list,
            "budget_warning_mobile_no_list": budget_warning_mobile_no_list
        }
        required_params.update(kwargs)
        return request_post(create_solution, required_params)

    @classmethod
    def modify_solution_status(cls, solution_id, status, **kwargs):
        """
        上架/下架花呗分期贴息

        https://paas.huifu.com/partners/api/#/hfq/api_hfq_hbfasxj
        :param solution_id:贴息方案实例id 创建花呗分期商家贴息接口 的返参solution_id，
        :param status: 状态控制
        :param kwargs: 非必填额外参数
        :return:
        """

        required_params = {
            "product_id": DGClient.mer_config.product_id,
            "solution_id": solution_id,
            "status": status
        }

        required_params.update(kwargs)
        return request_post(modify_solution_status, required_params)

    @classmethod
    def modify_pcredit_solution(cls, app_id, solution_id, start_time, end_time, **kwargs):
        """
        更新花呗分期商家贴息方案

        https://paas.huifu.com/partners/api/#/hfq/api_hfq_hbfqfagx
        :param solution_id:贴息方案实例id 创建花呗分期商家贴息接口 的返参solution_id，
        :param app_id: 开发者的应用ID
        :param start_time: 开发者的应用ID
        :param end_time: 开发者的应用ID
        :param kwargs: 非必填额外参数
        :return:
        """

        required_params = {
            "product_id": DGClient.mer_config.product_id,
            "solution_id": solution_id,
            "app_id": app_id,
            "start_time": start_time,
            "end_time": end_time
        }

        required_params.update(kwargs)
        return request_post(modify_solution, required_params)

    @classmethod
    def query_hb_solution(cls, solution_id, start_time, end_time, **kwargs):
        """
        查询花呗分期贴息账单

        https://paas.huifu.com/partners/api/#/hfq/api_hfq_hbfacx
        :param solution_id:贴息方案实例id 创建花呗分期商家贴息接口 的返参solution_id，
        :param start_time: 开发者的应用ID
        :param end_time: 开发者的应用ID
        :param kwargs: 非必填额外参数
        :return:
        """

        required_params = {
            "product_id": DGClient.mer_config.product_id,
            "solution_id": solution_id,
            "start_time": start_time,
            "end_time": end_time
        }

        required_params.update(kwargs)
        return request_post(query_solution, required_params)

    @classmethod
    def query_hb_activity(cls, solution_id, **kwargs):
        """
        花呗活动详情查询

        https://paas.huifu.com/partners/api/#/hfq/api_hfq_hbhdxqcx
        :param solution_id:贴息方案实例id 创建花呗分期商家贴息接口 的返参solution_id，
        :param kwargs: 非必填额外参数
        :return:
        """

        required_params = {
            "solution_id": solution_id
        }
        required_params.update(kwargs)
        return request_post(query_act_detail, required_params)



from dg_sdk.request_tools import request_post
from dg_sdk.pay.pay_api_urls import card_bind_apply, card_payment_confirm, card_payment_apply, \
    card_payment_page_pay, online_payment_query, online_payment_refund, online_payment_refund_query, \
    card_bind_confirm, card_un_bind, card_payment_sms, withhold_pay, customer_reg

from dg_sdk.dg_client import DGClient
from dg_sdk.pay.module.card import Card
from dg_sdk.pay.module.cert import Cert


class QuickAndHoldPay(object):
    """
    快捷支付与代扣相关接口，
    支付申请，首次四要素验证+发短信
    快捷支付确认
    快捷/代扣绑卡申请接口
    快捷/代扣绑卡确认接口
    快捷代扣解绑
    快捷代扣短信重发时使用
    快捷页面版
    代扣
    线上交易查询
    扫码交易列表查询
    退款
    退款查询
    线上快捷代扣用户注册接口
    """

    @classmethod
    def apply(cls,
              trans_amt,
              user_huifu_id,
              card_bind_id,
              notify_url,
              risk_check_data,
              terminal_device_data,
              extend_pay_data, **kwargs):
        """
        支付申请，首次四要素验证+发短信

        https://paas.huifu.com/partners/api/#/kuaijie/api_kjzfsq
        :param trans_amt: 交易金额
        :param user_huifu_id: 用户客户号
        :param card_bind_id: 绑卡ID
        :param notify_url: 异步通知地址#{http_server_url}，
        :param risk_check_data: 安全信息
        :param terminal_device_data: 设备数据
        :param extend_pay_data: 银行扩展字段
        :param kwargs: 非必填额外参数
        """
        required_params = {
            "transamt": trans_amt,
            "user_huifu_id": user_huifu_id,
            "card_bind_id": card_bind_id,
            "notify_url": notify_url,
            "risk_check_data": risk_check_data,
            "terminal_device_data": terminal_device_data,
            "extend_pay_data": extend_pay_data
        }
        required_params.update(kwargs)
        return request_post(card_payment_apply, required_params)

    @classmethod
    def bind_card(cls, order_id, order_date, card_info: Card, cert_info: Cert, **kwargs):
        """
        快捷/代扣绑卡申请接口
        :param order_id:订单号
        :param order_date:订单日期
        :param card_info:银行卡信息
        :param cert_info:证件信息
        :param kwargs: 非必填额外参数
        :return: 绑卡接口返回
        """
        required_params = {
            "order_id": order_id,
            "order_date": order_date,
            "card_id": card_info.card_id,
            "card_name": card_info.card_name,
            "cert_type": cert_info.cert_type,
            "cert_id": cert_info.cert_id,
            "cert_validity_type": cert_info.cert_validity_type,
            "cert_begin_date": cert_info.cert_begin_date,
            "cert_end_date": cert_info.cert_end_date,
            "card_mp": card_info.card_mp,
            "vip_code": card_info.vip_code,
            "expiration": card_info.expiration
        }
        required_params.update(kwargs)
        return request_post(card_bind_apply, required_params)

    @classmethod
    def bind_card_confirm(cls, order_id, order_date, out_cust_id, card_info: Card, cert_info: Cert,
                          **kwargs):
        """
        快捷/代扣绑卡确认接口
        :param order_id:订单号
        :param order_date:订单日期
        :param out_cust_id:顾客用户号
        :param card_info:银行卡信息
        :param cert_info:证件信息
        :param kwargs: 非必填额外参数
        :return: 绑卡接口返回
        """
        required_params = {
            "order_id": order_id,
            "order_date": order_date,
            "out_cust_id": out_cust_id,
            "card_id": card_info.card_id,
            "card_name": card_info.card_name,
            "card_mp": card_info.card_id,
            "vip_code": card_info.vip_code,
            "expiration": card_info.expiration,
            "cert_type": cert_info.cert_type,
            "cert_id": cert_info.cert_id,
            "cert_validity_type": cert_info.cert_validity_type,
            "cert_begin_date": cert_info.cert_begin_date,
            "cert_end_date": cert_info.cert_end_date,

        }
        required_params.update(kwargs)
        return request_post(card_bind_confirm, required_params)

    @classmethod
    def un_bind(cls, out_cust_id, token_no, **kwargs):
        """
        快捷/代扣解绑接口

        :param out_cust_id: 顾客用户号
        :param token_no: 卡令牌
        :param kwargs: 非必填额外参数
        :return: 解绑响应
        """
        required_params = {
            "out_cust_id": out_cust_id,
            "token_no": token_no
        }
        required_params.update(kwargs)
        return request_post(card_un_bind, required_params)

    @classmethod
    def confirm(cls, sms_code, req_date, req_seq_id, goods_desc, notify_url, **kwargs):
        """
        快捷支付确认

        https://paas.huifu.com/partners/api/#/kuaijie/api_kjzfqr
        :param sms_code: 短信验证码
        :param req_date: 原快捷支付申请请求时间
        :param goods_desc: 商品描述
        :param req_seq_id: 原快捷支付申请请求序列号
        :param notify_url: 异步通知地址
        :param kwargs: 非必填额外参数
        :return:
        """
        required_params = {
            "sms_code": sms_code,
            "goods_desc": goods_desc,
            "notify_url": notify_url,
            "req_date": req_date,
            "req_seq_id": req_seq_id
        }

        required_params.update(kwargs)
        return request_post(card_payment_confirm, required_params)

    @classmethod
    def sms_code(cls, out_cust_id, order_id, order_date, **kwargs):
        """
        快捷代扣短信重发(v1)
        :param out_cust_id: 顾客用户号
        :param order_id:订单号
        :param order_date:订单日期
        :param kwargs: 非必填额外参数
        :return:
        """
        required_params = {
            "out_cust_id": out_cust_id,
            "order_id": order_id,
            "order_date": order_date,
        }
        required_params.update(kwargs)
        return request_post(card_payment_sms, required_params)

    @classmethod
    def page(cls, trans_amt, notify_url, terminal_device_data, extend_pay_data, risk_check_data, **kwargs):
        """
        快捷支付页面版

        https://paas.huifu.com/partners/api/#/kuaijie/api_kjweb
        :param trans_amt: 交易金额
        :param notify_url: 异步通知地址
        :param terminal_device_data: 设备信息
        :param extend_pay_data:银行扩展信息
        :param risk_check_data: 安全信息
        :param kwargs: 非必填额外参数
        :return:
        """
        required_params = {
            "trans_amt": trans_amt,
            "notify_url": notify_url,
            "terminal_device_data": terminal_device_data,
            "extend_pay_data": extend_pay_data,
            "risk_check_data": risk_check_data
        }
        required_params.update(kwargs)
        return request_post(card_payment_page_pay, required_params)

    @classmethod
    def with_hold_pay(cls, trans_amt, card_bind_id, goods_desc, user_huifu_id, risk_check_data, **kwargs):
        """
        代扣
        :param trans_amt: 交易金额
        :param card_bind_id: 绑卡ID
        :param goods_desc: 商品描述
        :param user_huifu_id: 用户客户号
        :param risk_check_data: 安全信息
        :param kwargs: 非必填额外参数
        :return:
        """
        required_params = {
            "trans_amt": trans_amt,
            "card_bind_id": card_bind_id,
            "goods_desc": goods_desc,
            "user_huifu_id": user_huifu_id,
            "risk_check_data": risk_check_data
        }
        required_params.update(kwargs)
        return request_post(withhold_pay, required_params)

    @classmethod
    def query(cls, org_req_date, *, org_req_seq_id="", org_hf_seq_id="", pay_type="", **kwargs):
        """
        线上交易查询接口
        :param org_req_seq_id: 原始请求流水号
        :param org_req_date: 原始订单请求时间
        :param pay_type: 原交易支付类型, 快捷支付传quick_pay
        :param org_hf_seq_id: 交易返回的全局流水号
        :param kwargs: 非必填额外参数
        :return: 返回报文
        """
        required_params = {
            "org_req_date": org_req_date,
            "org_req_seq_id": org_req_seq_id,
            "org_hf_seq_id": org_hf_seq_id,
            "pay_type": pay_type
        }

        required_params.update(kwargs)

        return request_post(online_payment_query, required_params)

    @classmethod
    def refund(cls, ord_amt, org_req_date, *, org_req_seq_id="", org_hf_seq_id="", **kwargs):
        """
        线上退款接口
        :param ord_amt: 退款金额
        :param org_req_seq_id: 原始请求流水号
        :param org_req_date: 原始订单请求时间
        :param org_hf_seq_id: 交易返回的全局流水号
        :param kwargs: 非必填额外参数
        :return: 返回报文
        """

        required_params = {
            "ord_amt": ord_amt,
            "org_req_date": org_req_date,
            "org_req_seq_id": org_req_seq_id,
            "org_hf_seq_id": org_hf_seq_id,
        }

        required_params.update(kwargs)

        return request_post(online_payment_refund, required_params)

    @classmethod
    def refund_query(cls, org_req_date, *, org_req_seq_id="", org_hf_seq_id="", **kwargs):
        """
        线上退款查询接口
        :param org_req_seq_id: 原始请求流水号
        :param org_req_date: 原始退款请求时间
        :param org_hf_seq_id: 交易返回的全局流水号
        :param kwargs: 非必填额外参数
        :return: 返回报文
        """
        required_params = {
            "org_req_date": org_req_date,
            "org_req_seq_id": org_req_seq_id,
            "org_hf_seq_id": org_hf_seq_id,
        }
        required_params.update(kwargs)
        return request_post(online_payment_refund_query, required_params)

    @classmethod
    def customer_reg(cls, name, cert_type, cert_no, cert_validity_type, cert_begin_date, cert_end_date, mobile_no,
                     expand_id, **kwargs):
        """
        线上快捷代扣用户注册接口
        :param name: 个人姓名
        :param cert_type: 证件类型
        :param cert_no: 个人证件号
        :param cert_validity_type: 个人证件有效期类型
        :param cert_begin_date: 个人证件有效期起始日
        :param cert_end_date: 个人证件有效期到期日
        :param mobile_no: 手机号
        :param expand_id: 扩展方字段
        :param kwargs: 非必填额外参数
        :return:
        """
        required_params = {
            "product_id": DGClient.mer_config.product_id,
            "name": name,
            "cert_type": cert_type,
            "cert_no": cert_no,
            "cert_validity_type": cert_validity_type,
            "cert_begin_date": cert_begin_date,
            "cert_end_date": cert_end_date,
            "mobile_no": mobile_no,
            "expand_id": expand_id
        }
        required_params.update(kwargs)
        return request_post(customer_reg, required_params)



import unittest
from tests.conftest import *


class TestMerchant(unittest.TestCase):

    def setUp(self):
        dg_sdk.DGClient.mer_config = dg_sdk.MerConfig(private_key, public_key, sys_id, product_id, huifu_id)
        print("setup")

    def tearDown(self):
        print("tearDown")

    def test_query_merch_info(self):
        result = dg_sdk.Merchant.query_merch_info()
        assert result["resp_code"] == "00000000"

    def test_modify(self):
        result = dg_sdk.Merchant.modify(upper_huifu_id=upper_huifu_id)
        assert result["resp_code"] == "00000000"

    def test_download_file(self):
        result = dg_sdk.Merchant.download_bill(check_order_type="2", file_date="20211128")

        assert result["resp_code"] == "00000000"

    def test_upload(self):
        result = dg_sdk.Merchant.upload(file_type="F01", picture_path=pic_path)
        assert result["sub_resp_code"] == "00000000"

    def test_create_enterprise(self):
        merchant_info = dg_sdk.MerchantInfo(short_name="test",
                                            prov_id="350000",
                                            area_id="310100",
                                            district_id="350203",
                                            detail_addr="吉林省长春市思明区解放2路61686340",
                                            contact_name="test",
                                            contact_mobile_no="13111112222",
                                            contact_email="123@123.com",
                                            busi_type="1",
                                            receipt_name="盈盈超市",
                                            mcc="5411",
                                            service_phone="13133333333",
                                            sms_send_flag="0",
                                            login_name="test1123456")

        card_info = dg_sdk.MerCardInfo(card_type="1",
                                       card_name="陈立健",
                                       card_no="6225682141000002951",
                                       prov_id="310000",
                                       area_id="310100",
                                       bank_code="01030000",
                                       branch_name="中国农业银行股份有限公司上海马当路支行",
                                       cert_type="00",
                                       cert_no="321084198912066512",
                                       cert_validity_type="1",
                                       cert_begin_date="20121201",
                                       cert_end_date="20301201",
                                       mp="13700000214")
        lic_info = dg_sdk.BussinessLicInfo(reg_name="test",
                                           ent_type="1",
                                           license_code="20200513509363672",
                                           reg_prov_id="350000",
                                           reg_area_id="350200",
                                           reg_district_id="350203",
                                           reg_detail="吉林省长春市思明区解放2路61686340",
                                           license_validity_type="0",
                                           license_begin_date="20200401",
                                           license_end_date="20300101")

        legal_info = dg_sdk.LegalInfo(legal_name="陈立健",
                                      legal_cert_type="00",
                                      legal_cert_no="321084198912066512",
                                      legal_cert_validity_type="1",
                                      legal_cert_begin_date="20121201",
                                      legal_cert_end_date="20301201")
        settle_info = dg_sdk.SettleConfigInfo(settle_cycle="D1",
                                              min_amt="1.00",
                                              remained_amt="2.00",
                                              settle_abstract="abstract",
                                              out_settle_flag="2",
                                              out_settle_huifuid="",
                                              fixed_ratio="5.00")
        cash_config = dg_sdk.CashConfigInfo(cash_type="D0",
                                            fix_amt="1.00",
                                            fee_rate="0.11")
        cash_list = [cash_config]

        result = dg_sdk.Merchant.create_enterprise(upper_huifu_id=upper_huifu_id,
                                                   merch_info=merchant_info,
                                                   card_info=card_info,
                                                   lic_info=lic_info,
                                                   legal_person=legal_info,
                                                   settle_info=settle_info,
                                                   cash_config=cash_list)

        assert result["resp_code"] == "00000001"

    def test_create_individual(self):
        merchant_info = dg_sdk.MerchantInfo(short_name="test",
                                            prov_id="350000",
                                            area_id="310100",
                                            district_id="350203",
                                            detail_addr="吉林省长春市思明区解放2路61686340",
                                            contact_name="test",
                                            contact_mobile_no="13111112222",
                                            contact_email="123@123.com",
                                            busi_type="1",
                                            receipt_name="盈盈超市",
                                            mcc="5411",
                                            service_phone="13133333334",
                                            sms_send_flag="0",
                                            login_name="te1st1123456")

        card_info = dg_sdk.MerCardInfo(card_type="1",
                                       card_name="陈立健",
                                       card_no="6225682141000002951",
                                       prov_id="310000",
                                       area_id="310100",
                                       bank_code="01030000",
                                       branch_name="中国农业银行股份有限公司上海马当路支行",
                                       cert_type="00",
                                       cert_no="321084198912066512",
                                       cert_validity_type="1",
                                       cert_begin_date="20121201",
                                       cert_end_date="20301201",
                                       mp="13700000214")

        settle_info = dg_sdk.SettleConfigInfo(settle_cycle="D1",
                                              min_amt="1.00",
                                              remained_amt="2.00",
                                              settle_abstract="abstract",
                                              out_settle_flag="2",
                                              out_settle_huifuid="",
                                              fixed_ratio="5.00")
        cash_config = dg_sdk.CashConfigInfo(cash_type="D0",
                                            fix_amt="1.00",
                                            fee_rate="0.11")
        cash_list = [cash_config]

        result = dg_sdk.Merchant.create_individual(upper_huifu_id=upper_huifu_id,
                                                   reg_name="商户名称",
                                                   merch_info=merchant_info,
                                                   card_info=card_info,
                                                   settle_info=settle_info,
                                                   cash_config=cash_list)

        assert result["resp_code"] == "00000001"

    def test_modify_headquarters(self):
        result = dg_sdk.Merchant.modify_headquarters(chains_id="test",
                                                     name="总部123",
                                                     contact_name="联系人1",
                                                     contact_mobile_no="13122223333",
                                                     contact_cert_no="110101200208179198")

        assert result["resp_code"] == "00000003"

    def test_add_head(self):
        result = dg_sdk.Merchant.add_headquarters(name="总部123",
                                                  contact_name="联系人1",
                                                  contact_mobile_no="13122223333",
                                                  contact_cert_no="110101200208179198")

        assert result["resp_code"] == "00000003"

    def test_bind_headquarters(self):
        result = dg_sdk.Merchant.bind_headquarters(chains_id="test_id",
                                                   mer_type="0",
                                                   state="1"
                                                   )

        assert result["resp_code"] == "00000003"

    def test_acct_info(self):
        result = dg_sdk.Merchant.query_acct_info()
        assert result["sub_resp_code"] == "00000000"

    def test_reg_busi_info(self):
        result = dg_sdk.Merchant.reg_busi_info(upper_huifu_id, "2")
        assert result["resp_code"] == "00000000"

    def test_modify_busi_info(self):
        result = dg_sdk.Merchant.modify_busi_info()
        assert result["resp_code"] == "00000000"

    def test_query_apply_status(self):
        result = dg_sdk.Merchant.modify_busi_info()
        apply_no = result["apply_no"]
        result = dg_sdk.Merchant.query_apply_status(apply_no)
        assert result["resp_code"] == "00000000"

    def test_add_split_config(self):
        result = dg_sdk.Merchant.add_split_config(rule_origin="01",
                                                  repeal_flag="N",
                                                  refund_flag="N",
                                                  div_flag="N",
                                                  apply_ratio="50",
                                                  start_type="0")
        assert result["sub_resp_code"] == "90000000"

    def test_query_split_config(self):
        result = dg_sdk.Merchant.query_split_config()
        assert result["sub_resp_code"] == "00000000"

    def test_installment_config(self):
        result = dg_sdk.Merchant.installment_config()
        assert result["resp_code"] == "00000000"

    def test_query_installment_config(self):
        result = dg_sdk.Merchant.query_installment_config()
        assert result["resp_code"] == "00000000"

    def test_reg_activity(self):
        result = dg_sdk.Merchant.reg_activity(pay_way="W",
                                              fee_type="7",
                                              syt_photo="42204258-967e-373c-88d2-1afa4c7bb8ef",
                                              mm_photo="42204258-967e-373c-88d2-1afa4c7bb8ef",
                                              bl_photo="42204258-967e-373c-88d2-1afa4c7bb8ef",
                                              dh_photo="42204258-967e-373c-88d2-1afa4c7bb8ef")

        assert result["resp_code"] == "00000007"

    def test_query_activities(self):
        result = dg_sdk.Merchant.query_activities()

        assert result["resp_code"] == "00000000"

    def test_settlement_query(self):
        result = dg_sdk.Merchant.settlement_query(begin_date="20210910", end_date="20210911")

        assert result["resp_code"] == "00000000"



from dg_sdk.merchant.module.merchant_info import MerchantInfo
from dg_sdk.merchant.module.legal_info import LegalInfo
from dg_sdk.merchant.module.bussiness_lic_info import BussinessLicInfo
from dg_sdk.merchant.module.settle_config_info import SettleConfigInfo
from dg_sdk.merchant.module.cash_config_info import CashConfigInfo
from dg_sdk.merchant.module.mer_card_info import MerCardInfo
from dg_sdk.merchant.module.corp_info import CorpInfo
from dg_sdk.merchant.module.file_info import FileInfo
from dg_sdk.merchant.module.sales_info import SalesInfo
from dg_sdk.merchant.module.settlement_info import SettlementInfo
from dg_sdk.merchant.module.zft_split_receiver import ZFTSplitReceiver
from dg_sdk.merchant.module.zft_merchant_info import ZFTMerchantInfo



from dg_sdk.merchant.module.merchant_info import MerchantInfo


class ZFTMerchantInfo(MerchantInfo):
    """
    直付通商户经营信息
    """
    name = ""
    cert_no = ""
    cert_type = ""
    contact_tag = ""
    contact_type = ""

    def __init__(self, name, mcc, cert_type, cert_no, service_phone, prov_id, area_id, district_id, detail_addr,
                 contact_name, contact_tag, contact_type, contact_mobile_no):
        """
        直付通商户经营信息
        :param name:进件的二级商户名称
        :param mcc:商户类别码mcc
        :param cert_type:商户证件类型
        :param cert_no:商户证件编号
        :param service_phone:客服电话
        :param prov_id:经营省
        :param area_id:经营市
        :param district_id:经营区
        :param detail_addr:经营详细地址
        :param contact_name:联系人姓名
        :param contact_tag:	商户联系人业务标识
        :param contact_type:联系人类型，取值范围：LEGAL_PERSON：法人；CONTROLLER：实际控制人；AGENT：代理人；OTHER：其他
        :param contact_mobile_no:联系人手机号
        """

        super().__init__(name, prov_id, area_id, district_id, detail_addr, contact_name, contact_mobile_no,
                         "", "", "", mcc, service_phone)

        self.name = name
        self.cert_no = cert_no
        self.cert_type = cert_type
        self.contact_tag = contact_tag
        self.contact_type = contact_type

    def obj_to_dict(self):
        return {
            "name": self.name,
            "mcc": self.mcc,
            "cert_no": self.cert_no,
            "cert_type": self.cert_type,
            "service_phone": self.service_phone,
            "prov_id": self.prov_id,
            "area_id": self.area_id,
            "district_id": self.district_id,
            "detail_addr": self.detail_addr,
            "contact_name": self.contact_name,
            "contact_tag": self.contact_tag,
            "contact_type": self.contact_type,
            "contact_mobile_no": self.contact_mobile_no
        }



class FileInfo(object):
    """
    文件信息
    """
    file_type = ""
    file_id = ""
    file_name = ""

    def __init__(self, file_type, file_id, file_name):
        """
        文件信息
        :param file_type: 文件类型
        :param file_id: 文件ID
        :param file_name: 文件名称
        """
        self.file_type = file_type
        self.file_id = file_id
        self.file_name = file_name

    def obj_to_dict(self):
        return {
            "file_type": self.file_type,
            "file_id": self.file_id,
            "file_name": self.file_name
        }



from dg_sdk.request_tools import request_post
from dg_sdk.merchant.alimerchant_api_urls import *
from dg_sdk.merchant.merchant_api_urls import add_cert_info
from dg_sdk.dg_client import DGClient
from typing import List
from dg_sdk.merchant.module.file_info import FileInfo
from dg_sdk.merchant.module.zft_merchant_info import ZFTMerchantInfo
from dg_sdk.merchant.module.zft_split_receiver import ZFTSplitReceiver
import json


class AliMerchant(object):

    @classmethod
    def add_cert_info(cls, pay_way, app_id, file_list: List[FileInfo], **kwargs):
        """
        证书登记
        :param pay_way: 开通类型 W:微信 A:支付宝
        :param app_id: 支付宝：开发者应用ID，微信：服务商的APPID
        :param file_list: 证书文件列表
        :param kwargs: 非必填额外参数
        :return:
        """

        file_info_list = []
        if file_list:
            for file in file_list:
                file_info_list.append(file.obj_to_dict())

        required_params = {
            "product_id": DGClient.mer_config.product_id,
            "pay_way": pay_way,
            "app_id": app_id,
            "file_list": json.dumps(file_info_list)
        }

        required_params.update(kwargs)
        return request_post(add_cert_info, required_params)

    @classmethod
    def exchange_app_auth_token(cls, app_id, oper_type, **kwargs):
        """
        签约版-换取应用授权令牌
        :param oper_type: 0-换取令牌;1-刷新令牌
        :param app_id: 支付宝：开发者应用ID
        :param kwargs: 非必填额外参数
        :return:
        """

        required_params = {
            "product_id": DGClient.mer_config.product_id,
            "oper_type": oper_type,
            "app_id": app_id,
        }

        required_params.update(kwargs)
        return request_post(exchange_app_auth_token, required_params)

    @classmethod
    def apply_face2face_sign(cls, upper_huifu_id, direct_category, app_id, account, contact_name, contact_mobile_no,
                             contact_email, file_list: List[FileInfo], **kwargs):
        """
        签约版-申请当面付代签约
        :param upper_huifu_id: 渠道商汇付Id
        :param direct_category: 经营类目
        :param app_id: 开发者的应用ID
        :param account: 商户账号
        :param contact_name: 联系人姓名
        :param contact_mobile_no: 联系人手机号
        :param contact_email: 联系人电子邮箱
        :param file_list: 文件列表
        :param kwargs: 非必填额外参数
        :return:
        """

        file_info_list = []
        if file_list:
            for file in file_list:
                file_info_list.append(file.obj_to_dict())

        required_params = {
            "product_id": DGClient.mer_config.product_id,
            "app_id": app_id,
            "upper_huifu_id": upper_huifu_id,
            "direct_category": direct_category,
            "account": account,
            "contact_name": contact_name,
            "contact_mobile_no": contact_mobile_no,
            "contact_email": contact_email,
            "file_list": json.dumps(file_info_list)
        }
        required_params.update(kwargs)
        return request_post(apply_face_to_face_sign, required_params)

    @classmethod
    def query_apply_order_status(cls, app_id, **kwargs):
        """
        签约版-查询申请状态
        :param app_id: 开发者的应用ID
        :param kwargs: 非必填额外参数
        :return:
        """

        required_params = {
            "product_id": DGClient.mer_config.product_id,
            "app_id": app_id,
        }

        required_params.update(kwargs)
        return request_post(query_apply_order_status, required_params)

    @classmethod
    def zft_apply_register_mer(cls, merchant_info: ZFTMerchantInfo, service, sign_time_with_isv, default_settle_type,
                               file_list: List[FileInfo], **kwargs):
        """
        直付通-商户进件申请
        :param merchant_info: 商户经营信息
        :param service: 商户使用服务1：当面付、2：app支付、3：wap支付:4：电脑支付 多个英文逗号分隔
        :param sign_time_with_isv: 二级商户与服务商的签约时间格式:yyyy-MM-dd
        :param default_settle_type:默认结算类型bankCard/alipayAccount。bankCard表示结算到银行卡；alipayAccount表示结算到支付宝账号
        :param file_list:文件列表，附件资料列表fileList
        :param kwargs: 非必填额外参数
        :return:
        """
        file_info_list = []
        if file_list:
            for file in file_list:
                file_info_list.append(file.obj_to_dict())

        required_params = {
            "product_id": DGClient.mer_config.product_id,
            "service": service,
            "sign_time_with_isv": sign_time_with_isv,
            "default_settle_type": default_settle_type,
            "file_list": json.dumps(file_info_list)
        }
        required_params.update(merchant_info.obj_to_dict())
        required_params.update(kwargs)
        return request_post(reg_zft_mer_info, required_params)

    @classmethod
    def zft_split_config(cls, app_id, split_flag, receiver_list: List[ZFTSplitReceiver], status, **kwargs):
        """
        直付通-分账关系绑定&解绑
        :param app_id: 开发者的应用ID
        :param split_flag:分账开关1开通 2关闭
        :param receiver_list:分账接收方列表
        :param status:状态，0解绑 1绑定
        :param kwargs: 非必填额外参数
        :return:
        """
        zft_split_receiver_list = []
        if receiver_list:
            for receiver in receiver_list:
                zft_split_receiver_list.append(receiver.obj_to_dict())
        required_params = {
            "product_id": DGClient.mer_config.product_id,
            "app_id": app_id,
            "split_flag": split_flag,
            "status": status,
            "zft_split_receiver_list": json.dumps(zft_split_receiver_list)
        }

        required_params.update(kwargs)
        return request_post(config_zft_split_receiver, required_params)

    @classmethod
    def query_zft_split_config(cls, app_id, page_num, page_size, **kwargs):
        """
        直付通-分账关系查询
        :param app_id: 开发者的应用ID
        :param page_num: 页数起始页为 1
        :param page_size:页面大小。每页记录数，取值范围是(0,100]
        :param kwargs: 非必填额外参数
        :return:
        """

        required_params = {
            "product_id": DGClient.mer_config.product_id,
            "app_id": app_id,
            "page_num": page_num,
            "page_size": page_size
        }

        required_params.update(kwargs)
        return request_post(query_zft_split_receiver, required_params)



from dg_sdk.request_tools import request_post
from dg_sdk.pay.pay_api_urls import online_payment_query, online_payment_refund, online_payment_refund_query, \
    union_app_pay, wap_pay, web_page, bank_pay_payer_query, bank_pay_bank_list
from dg_sdk.dg_client import DGClient
import json


class OnlinePayment(object):
    """
    线上交易相关接口，
    银联APP支付，
    网银支付页面版，
    手机网页支付，
    线上交易退款，
    线上交易退款查询，
    线上交易交易查询
    网银付款银行账户接口
    网银支付银行列表查询接口
    """

    @classmethod
    def web_page(cls, trans_amt, goods_desc, goods_short_name, gw_chnnl_tp, biz_tp, notify_url, **kwargs):
        """
        网银支付页面版

        https://paas.huifu.com/partners/api/#/wy/api_wypc
        :param trans_amt: 订单金额
        :param goods_desc: 商品描述
        :param goods_short_name: 商品简称
        :param gw_chnnl_tp 网关支付受理渠道
        :param biz_tp 商品名
        :param notify_url 通知地址
        :param kwargs: 非必填额外参数
        :return:
        """

        required_params = {
            "trans_amt": trans_amt,
            "goods_desc": goods_desc,
            "extend_pay_data": json.dumps({
                "goods_short_name": goods_short_name,
                "gw_chnnl_tp": gw_chnnl_tp,
                "biz_tp": biz_tp
            }),
            "product_id": DGClient.mer_config.product_id,
            "notify_url": notify_url
        }

        required_params.update(kwargs)
        return request_post(web_page, required_params)

    @classmethod
    def union_app_create(cls, trans_amt, **kwargs):
        """
        银联APP支付

        https://paas.huifu.com/partners/api/#/api_unionapp
        :param trans_amt: 交易金额，单位为元，（例如：100.00）
        :param kwargs:  非必填额外参数
        :return: 支付对象
        """

        required_params = {
            "trans_amt": trans_amt,
        }

        required_params.update(kwargs)
        return request_post(union_app_pay, required_params)

    @classmethod
    def wap_page(cls, bank_card_no, front_url, trans_amt, **kwargs):
        """
        手机网页支付

        https://paas.huifu.com/partners/api/#/wy/api_wymobile
        :param bank_card_no: 银行卡号
        :param front_url: 前端跳转URL
        :param trans_amt: 交易金额
        :param kwargs: 非必填额外参数
        :return:
        """

        required_params = {
            "trans_amt": trans_amt,
            "bank_card_no": bank_card_no,
            "front_url": front_url,
        }

        required_params.update(kwargs)
        return request_post(wap_pay, required_params)

    @classmethod
    def query(cls, org_req_date, *, org_req_seq_id="", org_hf_seq_id="", pay_type="", **kwargs):
        """
        线上交易查询接口

        https://paas.huifu.com/partners/api/#/api_xsjycx
        :param org_req_seq_id: 原始请求流水号
        :param org_req_date: 原始订单请求时间
        :param pay_type: 原交易支付类型, 快捷支付传quick_pay
        :param org_hf_seq_id: 交易返回的全局流水号
        :param kwargs: 非必填额外参数
        :return: 返回报文
        """
        required_params = {
            "org_req_date": org_req_date,
            "org_req_seq_id": org_req_seq_id,
            "org_hf_seq_id": org_hf_seq_id,
            "pay_type": pay_type
        }

        required_params.update(kwargs)

        return request_post(online_payment_query, required_params, need_seq_id=False)

    @classmethod
    def refund(cls, ord_amt, org_req_date, *, org_req_seq_id="", org_hf_seq_id="", **kwargs):
        """
        线上退款接口

        https://paas.huifu.com/partners/api/#/api_xsjytk
        :param ord_amt: 退款金额
        :param org_req_seq_id: 原始请求流水号
        :param org_req_date: 原始订单请求时间
        :param org_hf_seq_id: 交易返回的全局流水号
        :param kwargs: 非必填额外参数
        :return: 返回报文
        """

        required_params = {
            "ord_amt": ord_amt,
            "org_req_date": org_req_date,
            "org_req_seq_id": org_req_seq_id,
            "org_hf_seq_id": org_hf_seq_id,
        }

        required_params.update(kwargs)

        return request_post(online_payment_refund, required_params)

    @classmethod
    def refund_query(cls, org_req_date, *, org_req_seq_id="", org_hf_seq_id="", **kwargs):
        """
        线上退款查询接口

        https://paas.huifu.com/partners/api/#/api_xsjytkcx
        :param org_req_seq_id: 原始请求流水号
        :param org_req_date: 原始退款请求时间
        :param org_hf_seq_id: 交易返回的全局流水号
        :param kwargs: 非必填额外参数
        :return: 返回报文
        """
        required_params = {
            "org_req_date": org_req_date,
            "org_req_seq_id": org_req_seq_id,
            "org_hf_seq_id": org_hf_seq_id,
        }
        required_params.update(kwargs)
        return request_post(online_payment_refund_query, required_params)

    @classmethod
    def payer_query(cls, org_req_date, org_req_seq_id, **kwargs):
        """
        网银付款银行账户查询接口

        https://paas.huifu.com/partners/api/#/wy/api_wyfkyhzhcx
        :param org_req_date: 原交易请求日期
        :param org_req_seq_id: 原交易请求流水号
        :param kwargs:
        :return:
        """
        required_params = {
            "org_req_date": org_req_date,
            "org_req_seq_id": org_req_seq_id,
        }
        required_params.update(kwargs)
        return request_post(bank_pay_payer_query, required_params)

    @classmethod
    def bank_list(cls, gate_type, order_type, **kwargs):
        """
        网银支付银行列表查询接口

        https://paas.huifu.com/partners/api/#/wy/api_wyzfyhlbcx
        :param gate_type: 网关支付类型 01：个人网关 02：企业网关
        :param order_type: 订单类型 P：支付 R：充值
        :param kwargs:
        :return:
        """
        required_params = {
            "gate_type": gate_type,
            "order_type": order_type,
        }
        required_params.update(kwargs)
        return request_post(bank_pay_bank_list, required_params)



from dg_sdk.dg_client import DGClient
from dg_sdk.core.rsa_utils import rsa_long_encrypt


class BankCard(object):
    """
    代发银行卡片对象
    """
    bank_account_name = ""  # 银行卡用户名
    bank_card_no_crypt = ""  # 银行账号
    bank_code = ""  # 银行编号
    card_acct_type = ""  # 对公对私标识
    province = ""  # 省份
    area = ""  # 地区

    def __init__(self, bank_account_name, bank_card_no, bank_code, card_acct_type, province, area):
        """
        代发银行卡片对象
        :param bank_account_name: 银行卡用户名
        :param bank_card_no: 银行账号
        :param bank_code: 银行编号
        :param card_acct_type: 对公对私标识
        :param province: 省份
        :param area: 地区
        """

        self.bank_account_name = bank_account_name
        self.bank_code = bank_code
        self.bank_card_no_crypt = rsa_long_encrypt(bank_card_no, DGClient.mer_config.public_key)
        self.card_acct_type = card_acct_type
        self.province = province
        self.area = area



import unittest
from tests.conftest import *


class TestTerminal(unittest.TestCase):

    def setUp(self):
        print("setup")

    def tearDown(self):
        print("tearDown")

    def test_terminal_add(self):
        result = dg_sdk.Terminal.add()
        assert result["resp_code"] == "20003"

    def test_terminal_cancel(self):
        result = dg_sdk.Terminal.cancel("12123123123123")

        assert result["resp_code"] == "20003"

    def test_terminal_list(self):
        result = dg_sdk.Terminal.query_list()

        assert result["resp_code"] == "20003"



from dg_sdk.request_tools import request_post
from dg_sdk.merchant.member_api_urls import *
from dg_sdk.merchant.module.legal_info import LegalInfo
from dg_sdk.merchant.module.bussiness_lic_info import BussinessLicInfo


class SettleAccount(object):
    """
    结算对象，包含以下接口
    创建结算账户对象
    删除结算账户对象
    查询结算配置记录
    结算记录分页查询接口
    """

    # TODO
    @classmethod
    def create(cls, reg_name,
               lic_info: BussinessLicInfo,
               legal_info: LegalInfo,
               contact_name,
               contact_mobile_no,
               **kwargs):
        """
        创建结算账户对象
        :param reg_name: 企业用户名称
        :param lic_info: 营业执照信息
        :param legal_info: 法人信息
        :param contact_name: 联系人姓名
        :param contact_mobile_no:联系人手机号
        :param kwargs: 非必填额外参数
        :return:
        """

        required_params = {
            "reg_name": reg_name,
            "contact_name": contact_name,
            "contact_mobile_no": contact_mobile_no
        }

        if lic_info:
            required_params.update(lic_info.obj_to_dict())
        if legal_info:
            required_params.update(legal_info.obj_to_dict())
        required_params.update(kwargs)
        return request_post(reg_usr_ent_base_info, required_params)

    @classmethod
    def delete(cls, name,
               cert_type,
               cert_no,
               cert_validity_type,
               cert_begin_date,
               mobile_no,
               cert_end_date="",
               **kwargs):
        """
        删除结算账户对象
        :param name: 个人姓名
        :param cert_type: 个人证件类型
        :param cert_no: 个人证件号码
        :param cert_validity_type: 个人证件有效期类型
        :param cert_begin_date:个人证件有效期开始日期
        :param mobile_no: 手机号
        :param cert_end_date: 个人证件有效期截止日期
        :param kwargs: 非必填额外参数
        :return:
        """

        required_params = {
            "name": name,
            "cert_type": cert_type,
            "cert_no": cert_no,
            "cert_validity_type": cert_validity_type,
            "cert_begin_date": cert_begin_date,
            "mobile_no": mobile_no,
            "cert_end_date": cert_end_date
        }

        required_params.update(kwargs)
        return request_post(reg_usr_indv_base_info, required_params)

    @classmethod
    def query_list(cls, name,
                   cert_type,
                   cert_no,
                   cert_validity_type,
                   cert_begin_date,
                   mobile_no,
                   cert_end_date="",
                   **kwargs):
        """
        查询结算配置记录
        :param name: 个人姓名
        :param cert_type: 个人证件类型
        :param cert_no: 个人证件号码
        :param cert_validity_type: 个人证件有效期类型
        :param cert_begin_date:个人证件有效期开始日期
        :param mobile_no: 手机号
        :param cert_end_date: 个人证件有效期截止日期
        :param kwargs: 非必填额外参数
        :return:
        """

        # todo

        required_params = {
            "name": name,
            "cert_type": cert_type,
            "cert_no": cert_no,
            "cert_validity_type": cert_validity_type,
            "cert_begin_date": cert_begin_date,
            "mobile_no": mobile_no,
            "cert_end_date": cert_end_date
        }

        required_params.update(kwargs)
        return request_post(reg_usr_indv_base_info, required_params)

    @classmethod
    def query_settle_trans(cls, **kwargs):
        """
        结算记录分页查询接口
        :param kwargs: 非必填额外参数
        :return:
        """
        return request_post(modify_usr_ent_base_info, **kwargs)



# 签约版-换取应用授权令牌
exchange_app_auth_token = "/ssproxy/direct/exchangeAppAuthToken"
# 签约版-申请当面付代签约
apply_face_to_face_sign = "/ssproxy/direct/applyFaceToFaceSign"
# 签约版-查询申请状态
query_apply_order_status = "/ssproxy/direct/queryApplyOrderStatus"
# 直付通-商户进件申请
reg_zft_mer_info = "/ssproxy/direct/regZftMerInfo"
# 直付通-分账关系绑定&解绑
config_zft_split_receiver = "/ssproxy/direct/configZftSplitReceiver"
# 直付通-分账关系查询
query_zft_split_receiver = "/ssproxy/direct/queryZftSplitReceiver"



class MerCardInfo(object):
    """
    卡信息
    """
    card_type = ""
    card_name = ""
    card_no = ""
    prov_id = ""
    area_id = ""
    bank_code = ""
    branch_code = ""
    branch_name = ""
    cert_type = ""
    cert_no = ""
    cert_validity_type = ""
    cert_begin_date = ""
    cert_end_date = ""
    mp = ""

    def __init__(self, card_type, card_name, card_no, prov_id, area_id,
                 bank_code="", branch_code="", branch_name="", cert_type="", cert_no="", cert_validity_type="",
                 cert_begin_date="", cert_end_date="", mp=""):
        """
        卡信息
        :param card_type: 卡类型0:对公 1：对私法人 2：对私非法人
        :param card_name: 卡户名
        :param card_no: 卡号
        :param prov_id: 银行所在省
        :param area_id: 银行所在市
        :param bank_code: 银行号
        :param branch_code: 支行联行号
        :param branch_name: 支行名称
        :param cert_type: 持卡人证件类型00:身份证 01:护照 02:军官证 03:士兵证 04:回乡证 05:户口本 06:外国护照 07:其他
        08:暂住证 09:警官证 10:文职干部证 11:港澳同胞回乡证
        :param cert_no: 持卡人证件号码
        :param cert_validity_type: 持卡人证件有效期类型，1:长期有效 0:非长期有效
        :param cert_begin_date: 持卡人证件有效期（起始）YYYYMMDD
        :param cert_end_date: 持卡人证件有效期（截止），长期有效可不填
        :param mp: 银行卡绑定手机号
        """

        self.card_type = card_type
        self.card_name = card_name
        self.card_no = card_no
        self.prov_id = prov_id
        self.area_id = area_id
        self.bank_code = bank_code
        self.branch_code = branch_code
        self.branch_name = branch_name
        self.cert_type = cert_type
        self.cert_no = cert_no
        self.cert_validity_type = cert_validity_type
        self.cert_begin_date = cert_begin_date
        self.cert_end_date = cert_end_date
        self.mp = mp

    def obj_to_dict(self):
        return {
            "card_type": self.card_type,
            "card_name": self.card_name,
            "card_no": self.card_no,
            "prov_id": self.prov_id,
            "area_id": self.area_id,
            "bank_code": self.bank_code,
            "branch_code": self.branch_code,
            "branch_name": self.branch_name,
            "cert_type": self.cert_type,
            "cert_no": self.cert_no,
            "cert_validity_type": self.cert_validity_type,
            "cert_begin_date": self.cert_begin_date,
            "cert_end_date": self.cert_end_date,
            "mp": self.mp
        }



from dg_sdk.merchant.module.settle_config_info import SettleConfigInfo
from dg_sdk.merchant.huabei import Huabei
from dg_sdk.merchant.ali_merchant import AliMerchant
from dg_sdk.merchant.wx_merchant import WXMerchant
from dg_sdk.merchant.uni_pay_merchant import UniPayMerchant
from dg_sdk.merchant.member import Member
from dg_sdk.merchant.merchant import Merchant
from dg_sdk.merchant.settle_account import SettleAccount
from dg_sdk.merchant.terminal import Terminal
from dg_sdk.merchant.module import *




class LegalInfo(object):
    """
    法人信息
    """
    legal_name = ""
    legal_cert_type = ""
    legal_cert_no = ""
    legal_cert_validity_type = ""
    legal_cert_begin_date = ""
    legal_cert_end_date = ""

    def __init__(self, legal_name, legal_cert_type, legal_cert_no, legal_cert_validity_type, legal_cert_begin_date,
                 legal_cert_end_date=""):
        """
        法人信息
        :param legal_name: 法人姓名
        :param legal_cert_type: 法人证件类型00:身份证 01:护照 02:军官证 03:士兵证 04:回乡证 05:户口本 06:外国护照 07:其他
        08:暂住证 09:警官证 10:文职干部证 11:港澳同胞回乡证
        :param legal_cert_no: 法人证件号码
        :param legal_cert_validity_type: 法人证件有效期类型1:长期有效 0:非长期有效
        :param legal_cert_begin_date: 法人证件有效期开始日期 yyyyMMdd
        :param legal_cert_end_date: 法人证件有效期截止日期，长期有效可不填 yyyyMMdd
        """
        self.legal_name = legal_name
        self.legal_cert_type = legal_cert_type
        self.legal_cert_no = legal_cert_no
        self.legal_cert_validity_type = legal_cert_validity_type
        self.legal_cert_begin_date = legal_cert_begin_date
        self.legal_cert_end_date = legal_cert_end_date

    def obj_to_dict(self):
        return {
            "legal_name": self.legal_name,
            "legal_cert_type": self.legal_cert_type,
            "legal_cert_no": self.legal_cert_no,
            "legal_cert_validity_type": self.legal_cert_validity_type,
            "legal_cert_begin_date": self.legal_cert_begin_date,
            "legal_cert_end_date": self.legal_cert_end_date
        }



import unittest
from tests.conftest import *


class TestRequestTools(unittest.TestCase):

    def setUp(self):
        print("setup")

    def tearDown(self):
        print("tearDown")

    def test_request_post_v2(self):
        params = {
            "trade_type": "A_NATIVE",
            "trans_amt": "0.01",
            "goods_desc": "goods_desc"
        }
        result = dg_sdk.DGTools.request_post(url="https://api.huifu.com/v2/trade/payment/jspay",
                                             request_params=params)
        assert result["resp_code"] == "00000100"

    def test_request_post_v2_2(self):
        params = {
            "trade_type": "A_NATIVE",
            "trans_amt": "0.01",
            "goods_desc": "goods_desc"
        }
        result = dg_sdk.DGTools.request_post(url="/v2/trade/payment/jspay",
                                             request_params=params)
        assert result["resp_code"] == "00000100"

    def test_request_post_v1(self):
        # dg_sdk.DGClient.mer_config = dg_sdk.MerConfig(private_key_v1, public_key_v1, sys_id_v1, product_id_v1,
        #                                               huifu_id_v1)
        request_params = {
            "huifu_id": huifu_id,
            "trade_type": "A_NATIVE",
            "trans_amt": "0.01",
            "goods_desc": "goods_desc",
            "notify_url": "virgo://http://www.xxx.com/getResp"
        }

        result = dg_sdk.DGTools.request_post("https://spin.cloudpnr.com/top/trans/pullPayInfo",
                                             request_params)
        assert result["resp_code"] == "10000000"

    def test_request_post_v1_2(self):
        # dg_sdk.DGClient.mer_config = dg_sdk.MerConfig(private_key_v1, public_key_v1, sys_id_v1, product_id_v1,
        #                                               huifu_id_v1)
        required_params = {
            "product_id": product_id
        }

        result = dg_sdk.DGTools.request_post("/ssproxy/queryMerchInfo",
                                             required_params)
        assert result["sub_resp_code"] == "00000000"



from dg_sdk.merchant.module.bussiness_lic_info import BussinessLicInfo
from dg_sdk.merchant.module.legal_info import LegalInfo
from dg_sdk.merchant.module.file_info import FileInfo
from typing import List


class CorpInfo(object):
    """
    企业信息
    """
    lic_info = ""
    legal_info = ""
    legal_mobile_no = ""
    allow_mer_use_chains_flag = ""
    file_list = ""
    category_one = ""
    category_two = ""

    def __init__(self, lic_info: BussinessLicInfo, legal_info: LegalInfo, legal_mobile_no, allow_mer_use_chains_flag,
                 file_list: List[FileInfo] = None, category_one="", category_two=""):
        """
        结算配置信息
        :param lic_info: 营业执照信息
        :param legal_info: 法人信息
        :param legal_mobile_no: 法人手机号
        :param allow_mer_use_chains_flag: 是否允许商户使用总部资质
        :param file_list: 文件列表
        :param category_one: 行业一级分类
        :param category_two: 行业二级分类
        """

        self.lic_info = lic_info
        self.legal_info = legal_info
        self.legal_mobile_no = legal_mobile_no
        self.allow_mer_use_chains_flag = allow_mer_use_chains_flag
        self.file_list = file_list
        self.category_one = category_one
        self.category_two = category_two

    def obj_to_dict(self):
        result = {
            "legal_mobile_no": self.legal_mobile_no,
            "allow_mer_use_chains_flag": self.allow_mer_use_chains_flag,
            "category_one": self.category_one,
            "category_two": self.category_two
        }
        result.update(self.lic_info.obj_to_dict())
        result.update(self.legal_info.obj_to_dict())

        if self.file_list:
            file_info_list = []
            for file in self.file_list:
                file_info_list.append(file.obj_to_dict())
            result["file_list"] = file_info_list

        return result



import unittest
from tests.conftest import *


class TestDGTools(unittest.TestCase):

    def setUp(self):

        print("setup")

    def tearDown(self):
        print("tearDown")

    def test_verfy_sign(self):
        data = {"resp_desc":"业务执行失败","req_seq_id":"202204181801142405249","req_date":"20220418","resp_code":"90000000","huifu_id":"6666000108854952"}
        sign = "CUWBV7RUGb0cvaxvnh97giA78Z5ZWKvlQOwTpNqLjigeKZSiWmp1EgPqjMZM/UnhNcpglLHZo/DFep3X05Ycdwsyqv7PkSnN/AXpi6UofQGsaxKaWNUokKfGN5TUWDsW6H843br0WNWMdRMAD1nmKj+B5pl8+HwjEv44hXUT6P+o/kPKZAlZLhBejT46L3mjoVSoiMxLpL7HSgUn43iWgCDEfWZLN6RNkn3/t/3UXtiwimc01Bqh+GbW/no95RN4BcYkJK18BjIhsLqtNvXHXkdcczofwpfa5EfEiR7h33cuqUvGGfpGbiSrxmqzoMF4kRGx242rD2nnSZZ6bIlnog=="
        result = dg_sdk.DGTools.verify_sign(data, sign)
        print(result)



from dg_sdk.request_tools import request_post
from dg_sdk.pay.pay_api_urls import card_trade_query


class Cloudmis(object):
    """
    智能终端mis接入
    """

    @classmethod
    def device_info(cls, device_id, json_data, **kwargs):
        """
        智能终端接入
        https://paas.huifu.com/partners/api/#/znmis/zn_sbtx
        :param device_id: 终端设备号
        :param json_data: 交易信息
        :param kwargs:  非必填额外参数
        :return: 支付对象
        """

        required_params = {
            "device_id": device_id,
            "json_data": json_data,
        }
        required_params.update(kwargs)
        return request_post(card_trade_query, required_params, need_seq_id=False)



from dg_sdk.request_tools import request_post
from dg_sdk.merchant.member_api_urls import *
from dg_sdk.dg_client import DGClient
from dg_sdk.merchant.module.legal_info import LegalInfo
from dg_sdk.merchant.module.bussiness_lic_info import BussinessLicInfo


class Member(object):
    """
    分账用户对象，包含以下接口
    企业用户基本信息注册
    个人用户基本信息注册
    查询账户信息
    企业用户基本信息修改
    个人用户基本信息修改
    用户业务入驻
    用户详情查询
    """

    @classmethod
    def create_enterprise(cls, short_name,
                          lic_info: BussinessLicInfo,
                          legal_info: LegalInfo,
                          contact_name,
                          contact_mobile,
                          **kwargs):
        """
        企业用户基本信息开户
        https://paas.huifu.com/partners/api/#/yhgl/api_yhgl_qyyhjbxxzc
        :param short_name: 企业用户名称
        :param lic_info: 营业执照信息
        :param legal_info: 法人信息
        :param contact_name: 联系人姓名
        :param contact_mobile:联系人手机号
        :param kwargs: 非必填额外参数
        :return:
        """

        required_params = {
            "short_name": short_name,
            "contact_name": contact_name,
            "contact_mobile": contact_mobile
        }

        if lic_info:
            required_params.update(lic_info.obj_to_dict())
        if legal_info:
            required_params.update(legal_info.obj_to_dict())
        required_params.update(kwargs)
        return request_post(reg_usr_ent_base_info, required_params)

    @classmethod
    def create_individual(cls, name,
                          cert_type,
                          cert_no,
                          cert_validity_type,
                          cert_begin_date,
                          mobile_no,
                          cert_end_date="",
                          **kwargs):
        """
        个人用户基本信息开户

        https://paas.huifu.com/partners/api/#/yhgl/api_yhgl_gryhjbxxzc
        :param name: 个人姓名
        :param cert_type: 个人证件类型
        :param cert_no: 个人证件号码
        :param cert_validity_type: 个人证件有效期类型
        :param cert_begin_date:个人证件有效期开始日期
        :param mobile_no: 手机号
        :param cert_end_date: 个人证件有效期截止日期
        :param kwargs: 非必填额外参数
        :return:
        """

        required_params = {
            "name": name,
            "cert_type": cert_type,
            "cert_no": cert_no,
            "cert_validity_type": cert_validity_type,
            "cert_begin_date": cert_begin_date,
            "mobile_no": mobile_no,
            "cert_end_date": cert_end_date
        }

        required_params.update(kwargs)
        return request_post(reg_usr_indv_base_info, required_params)

    @classmethod
    def modify_enter_base_info(cls, **kwargs):
        """
        企业用户基本信息修改

        https://paas.huifu.com/partners/api/#/yhgl/api_yhgl_qyyhjbxxxg
        :param kwargs: 非必填额外参数
        :return:
        """
        required_params = {

        }

        required_params.update(kwargs)
        return request_post(modify_usr_ent_base_info, required_params)

    @classmethod
    def modify_individual_base_info(cls, **kwargs):
        """
        个人用户基本信息修改

        https://paas.huifu.com/partners/api/#/yhgl/api_yhgl_gryhjbxxxg
        :param kwargs: 非必填额外参数
        :return:
        """
        required_params = {

        }

        required_params.update(kwargs)
        return request_post(modify_use_indv_base_info, required_params)

    @classmethod
    def reg_busi_info(cls, upper_huifu_id, **kwargs):
        """
        用户业务入驻

        https://paas.huifu.com/partners/api/#/yhgl/api_yhgl_ywrz
        :param upper_huifu_id: 渠道商汇付Id
        :param kwargs: 非必填额外参数
        :return:
        """

        required_params = {
            "product_id": DGClient.mer_config.product_id,
            "upper_huifu_id": upper_huifu_id
        }
        required_params.update(kwargs)
        return request_post(reg_usr_busi_info, required_params)

    @classmethod
    def query_user_detail(cls, **kwargs):
        """
        用户业务查询
        https://paas.huifu.com/partners/api/#/yhgl/api_yhgl_yhywcx
        :param kwargs: 非必填额外参数
        :return:
        """

        required_params = {
            "product_id": DGClient.mer_config.product_id,
        }
        required_params.update(kwargs)
        return request_post(query_user_detail, required_params)



class MerchantInfo(object):
    """
    商户经营信息
    """
    short_name = ""
    prov_id = ""
    area_id = ""
    district_id = ""
    detail_addr = ""
    contact_name = ""
    contact_mobile_no = ""
    contact_email = ""
    service_phone = ""
    sms_send_flag = ""
    login_name = ""
    busi_type = ""
    receipt_name = ""
    mcc = ""

    def __init__(self, short_name, prov_id, area_id, district_id, detail_addr, contact_name, contact_mobile_no,
                 contact_email, busi_type, receipt_name, mcc, service_phone, sms_send_flag="", login_name=""):
        """
        商户经营信息
        :param short_name: 商户简称
        :param prov_id: 经营省
        :param area_id: 经营市
        :param district_id: 经营区
        :param detail_addr: 经营详细地址
        :param contact_name: 联系人姓名
        :param contact_mobile_no: 联系人手机号
        :param contact_email: 联系人电子邮箱
        :param service_phone: 客服电话
        :param sms_send_flag: 是否发送短信通知商户，默认否, 1：短信通知联系人手机号
        :param login_name: 管理员账号，自定义值，必须全网唯一；作为控台的登陆用户名POS机的登陆用户名；为空不生成。
        :param busi_type: 经营类型1:实体 2:虚拟
        :param receipt_name: 小票名称，可以作为POS小票的名称
        :param mcc: 所属行业（MCC）
        """

        self.short_name = short_name
        self.prov_id = prov_id
        self.area_id = area_id
        self.district_id = district_id
        self.detail_addr = detail_addr
        self.contact_name = contact_name
        self.contact_mobile_no = contact_mobile_no
        self.contact_email = contact_email
        self.service_phone = service_phone
        self.sms_send_flag = sms_send_flag
        self.login_name = login_name
        self.busi_type = busi_type
        self.receipt_name = receipt_name
        self.mcc = mcc

    def obj_to_dict(self):
        return {
            "short_name": self.short_name,
            "prov_id": self.prov_id,
            "area_id": self.area_id,
            "district_id": self.district_id,
            "detail_addr": self.detail_addr,
            "contact_name": self.contact_name,
            "contact_mobile_no": self.contact_mobile_no,
            "contact_email": self.contact_email,
            "service_phone": self.service_phone,
            "sms_send_flag": self.sms_send_flag,
            "login_name": self.login_name,
            "busi_type": self.busi_type,
            "receipt_name": self.receipt_name,
            "mcc": self.mcc,
        }



from dg_sdk.request_tools import request_post
from dg_sdk.merchant.wxmerchant_api_urls import *
from dg_sdk.merchant.merchant_api_urls import add_cert_info
from dg_sdk.dg_client import DGClient
from typing import List
from dg_sdk.merchant.module.file_info import FileInfo
import json
from dg_sdk.merchant.module.sales_info import SalesInfo
from dg_sdk.merchant.module.settlement_info import SettlementInfo


class WXMerchant(object):
    """
    微信商户配置类，包含以下接口
    微信商户配置
    微信商户配置查询
    微信实名认证
    微信实名认证状态查询
    证书登记
    微信特约商户进件申请
    查询微信申请状态
    修改微信结算帐号
    查询微信结算账户
    微信关注配置
    微信关注配置查询
    """

    @classmethod
    def config(cls, fee_type, *, wx_woa_app_id="", wx_applet_app_id="", **kwargs):
        """
        微信商户配置

        https://paas.huifu.com/partners/api/#/shgl/shjj/api_shjj_wxshpz
        :param fee_type: 业务开通类型
        :param wx_woa_app_id: 公众号支付Appid
        :param wx_applet_app_id: 微信小程序APPID
        :param kwargs: 非必填额外参数
        :return:
        """

        required_params = {
            "fee_type": fee_type,
            "wx_woa_app_id": wx_woa_app_id,
            "wx_applet_app_id": wx_applet_app_id,
            "product_id": DGClient.mer_config.product_id
        }
        required_params.update(kwargs)
        return request_post(config, required_params)

    @classmethod
    def query_config(cls, **kwargs):
        """
        微信商户配置查询

        https://paas.huifu.com/partners/api/#/shgl/shjj/api_shjj_wxshpzcx
        :param kwargs: 非必填额外参数
        :return:
        """
        required_params = {
            "product_id": DGClient.mer_config.product_id,
        }
        required_params.update(kwargs)
        return request_post(query_config, required_params)

    @classmethod
    def realname(cls, name, mobile, id_card_number, **kwargs):
        """
        微信实名认证

        https://paas.huifu.com/partners/api/#/shgl/shjj/api_shjj_wxsmrz
        :param name: 联系人姓名
        :param mobile: 联系人手机号
        :param id_card_number: 联系人身份证号码
        :param kwargs: 非必填额外参数
        :return:
        """

        required_params = {
            "name": name,
            "mobile": mobile,
            "id_card_number": id_card_number
        }
        required_params.update(kwargs)
        return request_post(apply_wx_real_name, required_params)

    @classmethod
    def query_realname_state(cls, **kwargs):
        """
        查询微信实名认证
        https://paas.huifu.com/partners/api/#/shgl/shjj/api_shjj_wxsmrzztcx
        :return:
        """

        required_params = {
        }
        required_params.update(kwargs)
        return request_post(query_apply_wx_real_name, required_params)

    @classmethod
    def add_cert_info(cls, pay_way, app_id, file_list: List[FileInfo], **kwargs):
        """
        证书登记
        :param pay_way: 开通类型 W:微信 A:支付宝
        :param app_id: 支付宝：开发者应用ID，微信：服务商的APPID
        :param file_list: 证书文件列表
        :param kwargs: 非必填额外参数
        :return:
        """

        file_info_list = []
        if file_list:
            for file in file_list:
                file_info_list.append(file.obj_to_dict())

        required_params = {
            "product_id": DGClient.mer_config.product_id,
            "pay_way": pay_way,
            "app_id": app_id,
            "file_list": json.dumps(file_info_list)
        }

        required_params.update(kwargs)
        return request_post(add_cert_info, required_params)

    @classmethod
    def apply_register_mer(cls,
                           upper_huifu_id,
                           app_id,
                           mch_id,
                           owner,
                           sales_scenes_type,
                           sales_info: SalesInfo,
                           settlement_info: SettlementInfo,
                           **kwargs):
        """
        微信特约商户进件
        :param upper_huifu_id: 渠道商汇付Id
        :param app_id: 开发者的应用ID,服务商的APPID
        :param mch_id: 服务商的商户号
        :param owner: 经营者/法人是否为受益人
        :param sales_scenes_type:  经营场景类型，多个以英文逗号分割，SALES_SCENES_STORE 公众号：SALES_SCENES_MP
        小程序：SALES_SCENES_MINI_PROGRAM 互联网：SALES_SCENES_WEB APP：SALES_SCENES_APP 企业微信：SALES_SCENES_WEWORK
        :param sales_info: 经营场景
        :param settlement_info: 结算信息
        :param kwargs: 非必填额外参数
        :return:
        """

        required_params = {
            "product_id": DGClient.mer_config.product_id,
            "app_id": app_id,
            "upper_huifu_id": upper_huifu_id,
            "mch_id": mch_id,
            "owner": owner,
            "sales_scenes_type": sales_scenes_type,
            "sales_info": sales_info.obj_to_dict(),
            "settlement_info": settlement_info.obj_to_dict()
        }

        required_params.update(kwargs)
        return request_post(apply_wx_special_mer_sign, required_params)

    @classmethod
    def query_apply_reg(cls, app_id, mch_id, **kwargs):
        """
        查询微信申请状态
        :param app_id: 开发者的应用ID,服务商的APPID
        :param mch_id: 服务商的商户号
        :param kwargs: 非必填额外参数
        :return:
        """

        required_params = {
            "product_id": DGClient.mer_config.product_id,
            "app_id": app_id,
            "mch_id": mch_id,
        }

        required_params.update(kwargs)
        return request_post(query_wx_special_mer_sign, required_params)

    @classmethod
    def modify_settlement_info(cls, app_id, mch_id, sub_mchid, account_type, account_bank, bank_address_code,
                               account_number, **kwargs):
        """
        修改微信结算帐号
        :param app_id: 开发者的应用ID,服务商的APPID
        :param mch_id: 服务商的商户号
        :param sub_mchid: 特约商户号
        :param account_type: 账户类型
        :param account_bank: 开户银行
        :param bank_address_code: 开户银行省市编码
        :param account_number: 银行账号
        :param kwargs: 非必填额外参数
        :return:
        """

        required_params = {
            "product_id": DGClient.mer_config.product_id,
            "app_id": app_id,
            "mch_id": mch_id,
            "sub_mchid": sub_mchid,
            "account_type": account_type,
            "account_bank": account_bank,
            "bank_address_code": bank_address_code,
            "account_number": account_number,
        }

        required_params.update(kwargs)
        return request_post(modify_wx_settle_info, required_params)

    @classmethod
    def query_settlement_info(cls, app_id, mch_id, sub_mchid, **kwargs):
        """
        查询微信结算账户
        :param app_id: 开发者的应用ID,服务商的APPID
        :param mch_id: 服务商的商户号
        :param sub_mchid: 特约商户号
        :param kwargs: 非必填额外参数
        :return:
        """

        required_params = {
            "product_id": DGClient.mer_config.product_id,
            "app_id": app_id,
            "mch_id": mch_id,
            "sub_mchid": sub_mchid
        }

        required_params.update(kwargs)
        return request_post(query_wx_settle_info, required_params)

    @classmethod
    def subscribe_config(cls, app_id, mch_id, sub_mchid, **kwargs):
        """
        微信关注配置
        :param app_id: 开发者的应用ID,服务商的APPID
        :param mch_id: 服务商的商户号
        :param sub_mchid: 特约商户号
        :param kwargs: 非必填额外参数
        :return:
        """

        required_params = {
            "product_id": DGClient.mer_config.product_id,
            "app_id": app_id,
            "mch_id": mch_id,
            "sub_mchid": sub_mchid
        }

        required_params.update(kwargs)
        return request_post(wx_subscribe_config, required_params)

    @classmethod
    def query_subscribe_config(cls, app_id, mch_id, sub_mchid, **kwargs):
        """
        查询微信关注配置
        :param app_id: 开发者的应用ID,服务商的APPID
        :param mch_id: 服务商的商户号
        :param sub_mchid: 特约商户号
        :param kwargs: 非必填额外参数
        :return:
        """

        required_params = {
            "product_id": DGClient.mer_config.product_id,
            "app_id": app_id,
            "mch_id": mch_id,
            "sub_mchid": sub_mchid
        }

        required_params.update(kwargs)
        return request_post(query_wx_subscribe_config, required_params)



from dg_sdk.request_tools import request_post
from dg_sdk.pay.pay_api_urls import payment_confirm, payment_confirm_query, payment_confirm_refund, \
    payment_confirm_list, split_list


class Delaytrans(object):
    """
    延时交易，交易确认，交易确认查询，交易退款
    """

    @classmethod
    def confirm(cls, org_req_date="", org_req_seq_id="", org_hf_seq_id="", **kwargs):
        """
        交易确认 (org_req_seq_id,org_req_date)、org_hf_seq_id 两者必填其一

        https://paas.huifu.com/partners/api/#/smzf/api_jyqr
        :param org_req_date: 原交易请求日期
        :param org_req_seq_id: 原交易请求流水号
        :param org_hf_seq_id: 原交易汇付全局流水号
        :param kwargs: 非必填额外参数
        :return: 交易确认返回报文
        """
        required_params = {
            "org_hf_seq_id": org_hf_seq_id,
            "org_req_date": org_req_date,
            "org_req_seq_id": org_req_seq_id
        }

        required_params.update(kwargs)
        return request_post(payment_confirm, required_params)

    @classmethod
    def confirm_query(cls, org_req_date, org_req_seq_id, **kwargs):
        """
        交易确认查询 (org_req_seq_id,org_req_date)、org_hf_seq_id 两者必填其一

        https://paas.huifu.com/partners/api/#/smzf/api_jyqrcx
        :param org_req_date: 原交易请求日期
        :param org_req_seq_id: 原交易请求流水号
        :param kwargs: 非必填额外参数
        :return: 交易确认返回报文
        """
        required_params = {
            "org_req_date": org_req_date,
            "org_req_seq_id": org_req_seq_id
        }

        required_params.update(kwargs)
        return request_post(payment_confirm_query, required_params)

    @classmethod
    def query_confirm_list(cls, org_req_date, org_req_seq_id, **kwargs):
        """
        交易确认列表查询(v1) (org_req_seq_id,org_req_date)、org_hf_seq_id 两者必填其一
        :param org_req_date: 原交易请求日期
        :param org_req_seq_id: 原交易请求流水号
        :param kwargs: 非必填额外参数
        :return: 交易确认返回报文
        """
        required_params = {
            "trans_req_date": org_req_date,
            "trans_req_seq_id": org_req_seq_id
        }

        required_params.update(kwargs)
        return request_post(payment_confirm_list, required_params)

    @classmethod
    def split_list(cls, hf_seq_id, ord_type, **kwargs):
        """
        查询交易分账明细

        https://paas.huifu.com/partners/api/#/smzf/api_fzmxcx
        :param hf_seq_id: 全局流水号
        :param ord_type: 交易类型，consume：正向交易、refund：反向交易”
        :param kwargs:
        :return:
        """
        required_params = {
            "hf_seq_id": hf_seq_id,
            "ord_type": ord_type
        }
        required_params.update(kwargs)
        return request_post(split_list, required_params)

    @classmethod
    def confirm_refund(cls, org_req_date, org_req_seq_id, **kwargs):
        """
        交易确认退款

        https://paas.huifu.com/partners/api/#/smzf/api_jyqrtk
        :param org_req_date: 原交易请求日期
        :param org_req_seq_id: 原交易请求流水号
        :param kwargs: 非必填额外参数
        :return: 交易确认退款返回报文
        """
        required_params = {
            "org_req_date": org_req_date,
            "org_req_seq_id": org_req_seq_id
        }

        required_params.update(kwargs)
        return request_post(payment_confirm_refund, required_params)



from typing import List
from dg_sdk.merchant.module.file_info import FileInfo


class SalesInfo(object):
    """
    经营场景信息
    """
    biz_store_name = ""
    biz_address_code = ""
    biz_store_address = ""
    biz_sub_appid = ""
    mp_appid = ""
    mp_sub_appid = ""
    mini_program_appid = ""
    mini_program_sub_appid = ""
    app_appid = ""
    app_sub_appid = ""
    domain = ""
    file_list = ""
    web_appid = ""
    sub_corp_id = ""

    def __init__(self, biz_store_name, biz_address_code, biz_store_address, biz_sub_appid, mp_appid, mp_sub_appid,
                 mini_program_appid="", mini_program_sub_appid="", app_appid="", app_sub_appid="", domain="",
                 file_list: List[FileInfo] = None, web_appid="", sub_corp_id=""):
        """
        结算配置信息
        :param biz_store_name: 门店名称
        :param biz_address_code: 门店省市编码
        :param biz_store_address: 门店地址
        :param biz_sub_appid: 线下场所对应的商家APPID
        :param mp_appid: 服务商公众号APPID
        :param mp_sub_appid: 商家公众号APPID
        :param mini_program_appid: 服务商小程序APPID
        :param mini_program_sub_appid: 商家小程序APPID
        :param app_appid: 服务商应用APPID
        :param app_sub_appid: 商家应用APPID
        :param domain: 互联网网站域名
        :param file_list: 文件列表
        :param web_appid: 互联网网站对应的商家APPID
        :param sub_corp_id: 商家企业微信CorpID
        """

        self.biz_store_name = biz_store_name
        self.biz_address_code = biz_address_code
        self.biz_store_address = biz_store_address
        self.biz_sub_appid = biz_sub_appid
        self.mp_appid = mp_appid
        self.mp_sub_appid = mp_sub_appid
        self.mini_program_appid = mini_program_appid
        self.mini_program_sub_appid = mini_program_sub_appid
        self.app_appid = app_appid
        self.app_sub_appid = app_sub_appid
        self.domain = domain
        self.file_list = file_list
        self.web_appid = web_appid
        self.sub_corp_id = sub_corp_id

    def obj_to_dict(self):

        result = {
            "biz_store_name": self.biz_store_name,
            "biz_address_code": self.biz_address_code,
            "biz_store_address": self.biz_store_address,
            "biz_sub_appid": self.biz_sub_appid,
            "mp_appid": self.mp_appid,
            "mp_sub_appid": self.mp_sub_appid,
            "mini_program_appid": self.mini_program_appid,
            "mini_program_sub_appid": self.mini_program_sub_appid,
            "app_appid": self.app_appid,
            "app_sub_appid": self.app_sub_appid,
            "domain": self.domain,
            "web_appid": self.web_appid,
            "sub_corp_id": self.sub_corp_id
        }

        if self.file_list:
            file_info_list = []
            for file in self.file_list:
                file_info_list.append(file.obj_to_dict())
            result["file_list"] = file_info_list

        return result



# 企业类型商户进件
ent_mer_reg = "/v2/merchant/basicdata/ent"
# 个体户类型商户进件
indv_mer_reg = "/v2/merchant/basicdata/indv"
# 基本信息修改
mer_modify = "/v2/merchant/basicdata/modify"
# 详细信息查询
query_merch_info = "/v2/merchant/basicdata/query"
# 新增总部
add_chains_corp_info = "/v2/merchant/chains/corpinfo"
# 修改总部
modify_chains_corp_info = "/v2/merchant/chains/modify"
# 总部商户绑定&解除
bind_chains_mer = "/v2/merchant/chains/bind"
# 商户业务开通
reg_mer_busi_info = "/v2/merchant/busi/open"
# 商户业务开通修改
modify_mer_busi_info = "/v2/merchant/busi/modify"
# 申请单状态查询
query_apply_status = "/v2/merchant/basicdata/status/query"

# 对账单下载
mer_file_download = "/v2/trade/check/filequery"
# 商户分期配置
config_fq_mer_free = "/v2/pcredit/fee/config"
# 商户分期配置详情查询
query_fq_mer_free_detail = "/v2/pcredit/fee/detail"
# 活动报名，支持微信
reg_activities = "/v2/merchant/activity/add"
# 活动报名查询
query_act_url = "/v2/merchant/activity/query"
# 结算记录查询
settlement_query = '/v2/merchant/basicdata/settlement/query'

# 商户图片资料上传
mer_file_upload = "/ssproxy/file/upload"
# mer_file_upload = "/v2/supplementary/picture"

# 查询账户信息
query_acct_info_list = "/ssproxy/queryAcctInfoList"
# 商户分账配置
add_mer_split_config = "/ssproxy/addMerSplitConfig"
# 商户分账配置查询
query_mer_split_config = "/ssproxy/queryMerSplitConfig"


add_cert_info = "/ssproxy/direct/addCertInfo"



from dg_sdk.request_tools import request_post
from dg_sdk.pay.pay_api_urls import drawcash_create, drawcash_query


class Settlement(object):
    """
    取现相关接口，取现，取现交易查询
    """

    @classmethod
    def query(cls, org_req_date, *, org_req_seq_id="", org_hf_seq_id="", **kwargs):
        """
        取现交易查询
        :param org_req_date: 原机构请求日期
        :param org_req_seq_id: 原机构请求流水号
        :param org_hf_seq_id: 交易返回的全局流水号
        :param kwargs: 非必填额外参数
        :return: 返回报文
        """
        required_params = {
            "org_req_date": org_req_date,
            "org_req_seq_id": org_req_seq_id,
            "org_hf_seq_id": org_hf_seq_id,
        }

        required_params.update(kwargs)
        return request_post(drawcash_query, required_params)

    @classmethod
    def create(cls, cash_amt, token_no, into_acct_date_type, **kwargs):
        """
        取现
        :param cash_amt: 取现金额
        :param token_no: 取现卡序列号
        :param into_acct_date_type: 到账日期类型，["t0:t0单笔","t1:t1交易","d1:d1交易","t0b:t0批量"]
        :param kwargs: 非必填额外参数
        :return: 返回报文
        """
        required_params = {
            "cash_amt": cash_amt,
            "token_no": token_no,
            "into_acct_date_type": into_acct_date_type
        }
        required_params.update(kwargs)
        return request_post(drawcash_create, required_params)



import unittest
from tests.conftest import *


class TestOnlinePayment(unittest.TestCase):

    def setUp(self):
        print("setup")

    def tearDown(self):
        print("tearDown")

    def test_web_page(self):
        result = dg_sdk.OnlinePayment.web_page(trans_amt="0.01",
                                               goods_desc="goods_desc",
                                               goods_short_name="商品",
                                               gw_chnnl_tp="01",
                                               biz_tp="100001",
                                               notify_url="https://notify_url")
        assert isinstance(result, str)

    def test_union_app_create(self):
        pay_card_type = "Z"
        result = dg_sdk.OnlinePayment.union_app_create(trans_amt="0.01",
                                                       risk_check_data=risk_check_data,
                                                       pay_card_type=pay_card_type)

        assert result["resp_code"] == "22000004"

    def test_wap_page(self):
        result = dg_sdk.OnlinePayment.wap_page(bank_card_no="9558801001107141605",
                                               trans_amt="1.00",
                                               front_url="http://www.xxx.com/getresp",
                                               notify_url="virgo://http://192.168.25.213:30030/sspc/onlineAsync",
                                               extend_pay_data=extend_pay_data,
                                               risk_check_data=risk_check_data,
                                               terminal_device_data=terminal_device_data)

        assert result["data"].get("resp_code") == "90000000"

    def test_query(self):
        pay_card_type = "Z"
        result = dg_sdk.OnlinePayment.union_app_create(trans_amt="0.01",
                                                       risk_check_data=risk_check_data,
                                                       pay_card_type=pay_card_type)

        result = dg_sdk.OnlinePayment.query(org_req_date=result["req_date"],
                                            org_req_seq_id=result["req_seq_id"])

        assert result["resp_code"] == "23000001"

    def test_refund(self):
        pay_card_type = "Z"
        result = dg_sdk.OnlinePayment.union_app_create(trans_amt="0.01",
                                                       risk_check_data=risk_check_data,
                                                       pay_card_type=pay_card_type)

        result = dg_sdk.OnlinePayment.refund(ord_amt="0.01", org_req_date=result["req_date"],
                                             risk_check_data=risk_check_data,
                                             notify_url=notify_url,
                                             org_req_seq_id=result["req_seq_id"])

        assert result["resp_code"] == "23000001"

    def test_refund_query(self):
        pay_card_type = "Z"
        result = dg_sdk.OnlinePayment.union_app_create(trans_amt="0.01",
                                                       risk_check_data=risk_check_data,
                                                       pay_card_type=pay_card_type)
        result = dg_sdk.OnlinePayment.refund(ord_amt="0.01",
                                             org_req_date=result["req_date"],
                                             risk_check_data=risk_check_data,
                                             notify_url=notify_url,
                                             org_req_seq_id=result["req_seq_id"])
        result = dg_sdk.OnlinePayment.refund_query(org_req_date=result["req_date"],
                                                   org_req_seq_id=result["req_seq_id"])
        assert result["resp_code"] == "23000001"

    def test_payer_query(self):
        result = dg_sdk.OnlinePayment.payer_query(org_req_date="20220401",
                                                  org_req_seq_id="122312312312312")
        assert result["resp_code"] == "23000001"

    def test_bank_list(self):
        result = dg_sdk.OnlinePayment.bank_list(gate_type="01",
                                                order_type="P")
        assert result["resp_code"] == "00000000"



# 企业用户基本信息注册
reg_usr_ent_base_info = "/v2/user/basicdata/ent"
# 个人用户基本信息注册
reg_usr_indv_base_info = "/v2/user/basicdata/indv"
# 企业用户基本信息修改
modify_usr_ent_base_info = "/v2/user/basicdata/ent/modify"
# 个人用户基本信息修改
modify_use_indv_base_info = "/v2/user/basicdata/indv/modify"
# 用户业务入驻
reg_usr_busi_info = "/v2/user/busi/open"
# 用户业务查询
query_user_detail = "/v2/user/basicdata/query"



from dg_sdk.dg_client import DGClient
from dg_sdk.core.rsa_utils import rsa_long_encrypt


class Card(object):
    """
    银行卡片对象
    """
    card_id = ""  # 卡号
    card_name = ""  # 卡户姓名
    card_mp = ""  # 卡片手机号
    vip_code = ""  # 卡片安全码
    expiration = ""  # 卡片有效期

    def __init__(self, card_id, card_name, card_mp, vip_code="", expiration=""):
        self.card_id = rsa_long_encrypt(card_id, DGClient.mer_config.public_key)
        self.card_name = rsa_long_encrypt(card_name, DGClient.mer_config.public_key)
        self.card_mp = rsa_long_encrypt(card_mp, DGClient.mer_config.public_key)
        self.vip_code = rsa_long_encrypt(vip_code, DGClient.mer_config.public_key)
        self.expiration = rsa_long_encrypt(expiration, DGClient.mer_config.public_key)



from dg_sdk.request_tools import request_post
from dg_sdk.merchant.unipaymerchant_api_urls import *
from dg_sdk.dg_client import DGClient
from typing import List
from dg_sdk.merchant.module.file_info import FileInfo


class UniPayMerchant(object):

    @classmethod
    def apply_register_mer(cls, mer_type, legal_mobile, contract_id_no, file_list: List[FileInfo] = None, **kwargs):
        """
        云闪付活动商户入驻
        :param mer_type: 商户类型 MERCHANT_01-自然人; MERCHANT_02-个体工商户; MERCHANT_03-企业
        :param legal_mobile: 负责人手机号
        :param contract_id_no: 联系人身份证号
        :param file_list: 附件资料列表 fileList
        :param kwargs: 非必填额外参数
        :return:
        """

        file_info_list = []
        if file_list:
            for file in file_list:
                file_info_list.append(file.obj_to_dict())

        required_params = {
            "product_id": DGClient.mer_config.product_id,
            "mer_type": mer_type,
            "legal_mobile": legal_mobile,
            "contract_id_no": contract_id_no,
            "file_list": file_info_list
        }

        required_params.update(kwargs)
        return request_post(reg_mer_base_info, required_params)

    @classmethod
    def query_apply_reg(cls, serial_no, **kwargs):
        """
        云闪付活动商户入驻状态查询
        :param serial_no: 工单号参考 云闪付活动商户入驻接口 的返参serial_no
        :param kwargs: 非必填额外参数
        :return:
        """

        required_params = {
            "product_id": DGClient.mer_config.product_id,
            "serial_no": serial_no,
        }

        required_params.update(kwargs)
        return request_post(query_mer_reg_stat, required_params)

    @classmethod
    def query_mer_base_info(cls, mer_no, **kwargs):
        """
        云闪付活动商户详细信息查询
        :param mer_no: 渠道商汇付Id
        :param kwargs: 非必填额外参数
        :return:
        """

        required_params = {
            "product_id": DGClient.mer_config.product_id,
            "mer_no": mer_no,
        }
        required_params.update(kwargs)
        return request_post(query_mer_base, required_params)

    @classmethod
    def query_activity_list(cls, **kwargs):
        """
        云闪付活动列表查询
        :param kwargs: 非必填额外参数
        :return:
        """

        required_params = {
            "product_id": DGClient.mer_config.product_id,
        }

        required_params.update(kwargs)
        return request_post(query_act_list, required_params)

    @classmethod
    def enlist_activity(cls, activity_id, mer_no, **kwargs):
        """
        云闪付活动报名
        :param activity_id: 商户使用服务1：当面付、2：app支付、3：wap支付:4：电脑支付 多个英文逗号分隔
        :param mer_no: 二级商户与服务商的签约时间格式:yyyy-MM-dd
        :param kwargs: 非必填额外参数
        :return:
        """

        required_params = {
            "product_id": DGClient.mer_config.product_id,
            "activity_id": activity_id,
            "mer_no": mer_no,
        }
        required_params.update(kwargs)
        return request_post(enlist_act, required_params)

    @classmethod
    def query_enlish_activity_status(cls, enlist_id="", serial_number="", **kwargs):
        """
        云闪付活动报名进度查询
        :param enlist_id: 报名编号，与serialNumber二选一
        :param serial_number:报名请求流水号，与enlistId二选一 报名时传递的reqSysId
        :param kwargs: 非必填额外参数
        :return:
        """

        required_params = {
            "product_id": DGClient.mer_config.product_id,
            "enlist_id": enlist_id,
            "serial_number": serial_number,
        }

        required_params.update(kwargs)
        return request_post(query_en_list_act_stat, required_params)



from dg_sdk.request_tools import request_post
from dg_sdk.pay.pay_api_urls import scan_payment_create, scan_payment_close, \
    scan_payment_query, scan_payment_refund, scan_payment_refund_query, offline_payment_scan, \
    scan_payment_close_query, union_user_id, payment_confirm_query, payment_confirm_refund, payment_confirm


class ScanPayment(object):
    """
    聚合正扫，聚合反扫，交易查询，交易退款，退款查询，关单
    """

    @classmethod
    def create(cls, trade_type, trans_amt, goods_desc, **kwargs):
        """
        创建聚合正扫订单
        :param trade_type: 微信公众号-T_JSAPI 小程序-T_MINIAPP 支付宝JS-A_JSAPI 支付宝正扫-A_NATIVE 银联正扫-U_NATIVE
        银联JS-U_JSAPI 数字货币二维码支付-D_NATIVE
        :param trans_amt: 交易金额，单位为元，（例如：100.00）
        :param goods_desc: 商品描述
        :param kwargs:  非必填额外参数
        :return: 支付对象
        """

        required_params = {
            "trade_type": trade_type,
            "trans_amt": trans_amt,
            "goods_desc": goods_desc,
        }

        required_params.update(kwargs)
        return request_post(scan_payment_create, required_params)

    @classmethod
    def micro_create(cls, trans_amt, goods_desc, auth_code, risk_check_data, **kwargs):
        """
        聚合反扫
        :param trans_amt: 交易金额
        :param goods_desc: 商品描述
        :param auth_code: 支付授权码
        :param risk_check_data: 风控信息
        :param kwargs: 非必填额外参数
        :return: 支付结果
        """
        required_params = {
            "auth_code": auth_code,
            "trans_amt": trans_amt,
            "goods_desc": goods_desc,
            "risk_check_data": risk_check_data
        }

        required_params.update(kwargs)
        return request_post(offline_payment_scan, required_params)

    @classmethod
    def query(cls, org_req_date, *, org_req_seq_id="", org_hf_seq_id="", party_order_id="", out_trans_id="", **kwargs):
        """
        支付查询
        :param org_req_date: 原始订单请求时间
        :param party_order_id: 微信支付宝的商户单号
        :param org_hf_seq_id: 交易返回的全局流水号
        :param out_trans_id: 微信支付宝的订单号
        :param org_req_seq_id: 原始请求流水号
        :param kwargs: 非必填额外参数
        :return: 支付对象
        """

        required_params = {
            "org_req_date": org_req_date,
            "org_req_seq_id": org_req_seq_id,
            "org_hf_seq_id": org_hf_seq_id,
            "party_order_id": party_order_id,
            "out_trans_id": out_trans_id,
        }

        required_params.update(kwargs)
        return request_post(scan_payment_query, required_params, need_seq_id=False)

    @classmethod
    def refund(cls, ord_amt, org_req_date, *, org_req_seq_id="", org_hf_seq_id="", org_party_order_id="", **kwargs):
        """
        发起退款
        :param ord_amt: 退款金额
        :param org_req_seq_id: 原始请求流水号
        :param org_req_date: 原始订单请求时间
        :param org_party_order_id: 微信支付宝的商户单号
        :param org_hf_seq_id: 交易返回的全局流水号
        :param kwargs: 非必填额外参数
        :return: 返回报文
        """

        required_params = {
            "ord_amt": ord_amt,
            "org_req_date": org_req_date,
            "org_req_seq_id": org_req_seq_id,
            "org_hf_seq_id": org_hf_seq_id,
            "org_party_order_id": org_party_order_id,
        }

        required_params.update(kwargs)

        return request_post(scan_payment_refund, required_params)

    @classmethod
    def refund_query(cls, org_req_date, *, org_req_seq_id="", org_hf_seq_id="", **kwargs):
        """
        退款查询
        :param org_req_seq_id: 原始请求流水号
        :param org_req_date: 原始退款请求时间
        :param org_hf_seq_id: 交易返回的全局流水号
        :param kwargs: 非必填额外参数
        :return: 退款对象
        """
        required_params = {
            "org_req_date": org_req_date,
            "org_req_seq_id": org_req_seq_id,
            "org_hf_seq_id": org_hf_seq_id,
        }
        required_params.update(kwargs)
        return request_post(scan_payment_refund_query, required_params, need_seq_id=False)

    @classmethod
    def close(cls, org_req_date, *, org_req_seq_id="", org_hf_seq_id="", **kwargs):
        """
        关单请求
        :param org_req_seq_id: 原始订单请求流水号
        :param org_req_date: 原始订单请求日期
        :param org_hf_seq_id: 交易返回的全局流水号
        :param kwargs: 非必填额外参数
        :return: 关单对象
        """
        required_params = {
            "org_hf_seq_id": org_hf_seq_id,
            "org_req_date": org_req_date,
            "org_req_seq_id": org_req_seq_id
        }

        required_params.update(kwargs)
        return request_post(scan_payment_close, required_params)

    @classmethod
    def close_query(cls, org_req_date, *, org_req_seq_id="", org_hf_seq_id="", **kwargs):
        """
        关单查询请求
        :param org_req_seq_id: 原始订单请求流水号
        :param org_req_date: 原始订单请求日期
        :param org_hf_seq_id: 交易返回的全局流水号
        :param kwargs: 非必填额外参数
        :return: 关单对象
        """
        required_params = {
            "org_hf_seq_id": org_hf_seq_id,
            "org_req_date": org_req_date,
            "org_req_seq_id": org_req_seq_id
        }

        required_params.update(kwargs)
        return request_post(scan_payment_close_query, required_params)

    @classmethod
    def union_user_id(cls, auth_code, app_up_identifier='CloudPay', **kwargs):
        """
        获取银联用户标识
        :param app_up_identifier: 银联支付标识,浏览器agent
        :param auth_code: 用户授权码
        :param kwargs: 非必填额外参数
        :return: 银联用户标识
        """
        required_params = {
            "auth_code": auth_code,
            "app_up_identifier": app_up_identifier
        }

        required_params.update(kwargs)
        return request_post(union_user_id, required_params)

    @classmethod
    def confirm(cls, org_req_date="", org_req_seq_id="", org_hf_seq_id="", **kwargs):
        """
        交易确认 (org_req_seq_id,org_req_date)、org_hf_seq_id 两者必填其一
        :param org_req_date: 原交易请求日期
        :param org_req_seq_id: 原交易请求流水号
        :param org_hf_seq_id: 原交易汇付全局流水号
        :param kwargs: 非必填额外参数
        :return: 交易确认返回报文
        """
        required_params = {
            "org_hf_seq_id": org_hf_seq_id,
            "org_req_date": org_req_date,
            "org_req_seq_id": org_req_seq_id
        }

        required_params.update(kwargs)
        return request_post(payment_confirm, required_params)

    @classmethod
    def confirm_refund(cls, org_req_date, org_req_seq_id, **kwargs):
        """
        交易确认退款
        :param org_req_date: 原交易请求日期
        :param org_req_seq_id: 原交易请求流水号
        :param kwargs: 非必填额外参数
        :return: 交易确认退款返回报文
        """
        required_params = {
            "org_req_date": org_req_date,
            "org_req_seq_id": org_req_seq_id
        }

        required_params.update(kwargs)
        return request_post(payment_confirm_refund, required_params)

    @classmethod
    def confirm_query(cls, org_req_date, org_req_seq_id, **kwargs):
        """
        交易确认查询 (org_req_seq_id,org_req_date)、org_hf_seq_id 两者必填其一
        :param org_req_date: 原交易请求日期
        :param org_req_seq_id: 原交易请求流水号
        :param kwargs: 非必填额外参数
        :return: 交易确认返回报文
        """
        required_params = {
            "org_req_date": org_req_date,
            "org_req_seq_id": org_req_seq_id
        }

        required_params.update(kwargs)
        return request_post(payment_confirm_query, required_params)



import unittest
from tests.conftest import *


class TestCloudmis(unittest.TestCase):

    def setUp(self):
        print("setup")

    def tearDown(self):
        print("tearDown")

    def test_device_info(self):
        result = dg_sdk.Cloudmis.device_info("fdadfasdfsdfsdfs", "test")
        assert result["resp_code"] == "10000000"



import unittest

import dg_sdk
from tests.conftest import *


class TestSettlement(unittest.TestCase):

    def setUp(self):
        dg_sdk.DGClient.mer_config = dg_sdk.MerConfig(private_key, public_key, sys_id, product_id, huifu_id)

        print("setup")

    def tearDown(self):
        print("tearDown")

    def test_create(self):
        result = dg_sdk.Settlement.create(cash_amt="0.01",
                                          token_no="121231312",
                                          into_acct_date_type="D1")

        assert result["resp_code"] == "22000005"

    def test_query(self):
        result = dg_sdk.Settlement.query("20211123", org_req_seq_id="dsfasdfs")

        assert result["resp_code"] == "23000001"



import json
import unittest

import dg_sdk
from tests.conftest import *


class TestQuickAndHoldPay(unittest.TestCase):

    def setUp(self):
        print("setup")

    def tearDown(self):
        print("tearDown")

    def test_apply(self):
        result = dg_sdk.QuickAndHoldPay.apply("0.02", "test", "test",
                                              notify_url,
                                              risk_check_data,
                                              terminal_device_data,
                                              extend_pay_data)
        assert result["resp_code"] == "22000001"

    def test_bind_card(self):
        card_info = dg_sdk.Card("6225751103859172", "李四", "13133332222")
        cert_info = dg_sdk.Cert("00", "310475110386223510", "0", "20210401", "20310401")

        result = dg_sdk.QuickAndHoldPay.bind_card("123123123123132",
                                                  "20220401",
                                                  card_info,
                                                  cert_info)
        assert result["resp_code"] == "20003"

    def test_bind_card_confirm(self):
        card_info = dg_sdk.Card("6225751103859172", "李四", "13133332222")
        cert_info = dg_sdk.Cert("00", "310475110386223510", "0", "20210401", "20310401")

        result = dg_sdk.QuickAndHoldPay.bind_card_confirm("123123123123132",
                                                          "20220401",
                                                          "out_cust_id",
                                                          card_info,
                                                          cert_info)
        assert result["resp_code"] == "20003"

    def test_unbind(self):
        result = dg_sdk.QuickAndHoldPay.un_bind("123123123123132",
                                                "20220401")
        assert result["resp_code"] == "20003"

    def test_confirm(self):
        result = dg_sdk.QuickAndHoldPay.confirm("121212",
                                                "20220401",
                                                "123123123123132",
                                                "goods_desc",
                                                "notify_url")
        assert result["resp_code"] == "23000004"

    def test_sms_code(self):
        result = dg_sdk.QuickAndHoldPay.sms_code("121212",
                                                 "123123123123132",
                                                 "20220401")
        assert result["sub_resp_code"] == "20003"

    def test_page(self):
        result = dg_sdk.QuickAndHoldPay.page("10.11",
                                             "http://www.baidu.com",
                                             terminal_device_data,
                                             extend_pay_data,
                                             risk_check_data)
        assert result

    @pytest.mark.skip(reason="没找到文档")
    def test_with_hold_pay(self):
        result = dg_sdk.QuickAndHoldPay.with_hold_pay("10.11",
                                                      "card_band_id",
                                                      "goods_desc",
                                                      "user_huifu_id",
                                                      risk_check_data)
        assert result["resp_code"] == "20003"

    def test_customer_reg(self):
        result = dg_sdk.QuickAndHoldPay.customer_reg("詹上",
                                                     "00",
                                                     "310481198804222210",
                                                     "0",
                                                     "20210101",
                                                     "20231010",
                                                     "13122223333",
                                                     "dfasdfsdfs")
        assert result["resp_code"] == "00000003"



from dg_sdk.pay.scan_payment import ScanPayment
from dg_sdk.pay.acct_payment import AcctPayment
from dg_sdk.pay.delaytrans import Delaytrans
from dg_sdk.pay.settlement import Settlement
from dg_sdk.pay.quick_and_hold_pay import QuickAndHoldPay
from dg_sdk.pay.online_payment import OnlinePayment
from dg_sdk.pay.surrogate import Surrogate
from dg_sdk.pay.installment import Installment
from dg_sdk.pay.pos import POS
from dg_sdk.pay.cloudmis import Cloudmis
from dg_sdk.pay.module import *



import unittest
import dg_sdk
from tests.conftest import *


class TestSurrogate(unittest.TestCase):

    def setUp(self):
        dg_sdk.DGClient.mer_config = dg_sdk.MerConfig(private_key, public_key, sys_id, product_id, huifu_id)
        print("setup")

    def tearDown(self):
        print("tearDown")

    def test_create(self):
        bank_card_info = dg_sdk.BankCard("张三", "6225098778909876", "00201", "01", "00121", "000213")

        result = dg_sdk.Surrogate.create(cash_amt="0.01",
                                         bank_card_info=bank_card_info,
                                         into_acct_date_type="D1",
                                         purpose_desc="puropose")

        assert result["resp_code"] == "10000000"

    def test_query(self):
        result = dg_sdk.Surrogate.query("20211123", org_req_seq_id="dsfasdfs")

        assert result["resp_code"] == "23000001"



import unittest
from tests.conftest import *


class TestHuabei(unittest.TestCase):

    def setUp(self):
        print("setup")

    def tearDown(self):
        print("tearDown")

    def test_config(self):
        result = dg_sdk.WXMerchant.config(fee_type="01", wx_applet_app_id="ssdfadf")
        assert result["resp_code"] == "00000002"

    def test_query_config(self):
        result = dg_sdk.WXMerchant.query_config()
        assert result["resp_code"] == "00000000"

    def test_realname(self):
        result = dg_sdk.WXMerchant.realname(name="李四",
                                            mobile="13233332222",
                                            id_card_number="3104222233222222")
        assert result["resp_code"] == "00000000"

    def test_query_realname_state(self):
        result = dg_sdk.WXMerchant.query_realname_state()
        assert result["resp_code"] == "00000000"



import unittest
from tests.conftest import *


class TestAcctPayment(unittest.TestCase):

    def setUp(self):
        print("setup")

    def tearDown(self):
        print("tearDown")

    def test_acct_payment_create(self):
        split_branch = "{\"acct_infos\":[{\"div_amt\":\"0.01\",\"huifu_id\":\"6666000018344461\"}]}"

        result = dg_sdk.AcctPayment.create("0.01", split_branch, risk_check_data, out_huifu_id="6666000108854952")
        assert result["resp_code"] == "22000002"

    def test_acct_payment_query(self):
        result = dg_sdk.AcctPayment.query("20211123", org_req_seq_id="testsstest")
        assert result["resp_code"] == "23000001"

    def test_acct_payment_refund(self):
        result = dg_sdk.AcctPayment.refund("0.01", "20211123", org_req_seq_id="dsfasdfs")
        assert result["resp_code"] == "23000001"

    def test_acct_refund_query(self):
        result = dg_sdk.AcctPayment.refund_query("20211123", org_req_seq_id="dsfasdfs")
        assert result["resp_code"] == "23000001"

    def test_balance_query(self):
        result = dg_sdk.AcctPayment.balance_query()
        assert result["resp_code"] == "00000000"



# 云闪付活动商户入驻
reg_mer_base_info = "/ssproxy/registeMerBaseInfo"
# 云闪付活动商户入驻状态查询
query_mer_reg_stat = "/ssproxy/queryMerRegisteStatus"
# 云闪付活动商户详细信息查询
query_mer_base = "/ssproxy/queryMerBaseInfo"
# 云闪付活动列表查询
query_act_list = "/ssproxy/queryActivityList"
# 云闪付活动报名
enlist_act = "/ssproxy/enlistActivity"
# 云闪付活动报名进度查询
query_en_list_act_stat = "/ssproxy/queryEnlistActivityStatus"



class ZFTSplitReceiver(object):
    """
    分账接收方
    """
    split_type = ""
    account = ""
    name = ""
    memo = ""

    def __init__(self, split_type, account, name="", memo=""):
        """
        分账接收方
        :param split_type: 文件类型
        :param account: 文件ID
        :param name: 文件名称
        :param memo: 分账关系描述
        """
        self.split_type = split_type
        self.account = account
        self.name = name
        self.memo = memo

    def obj_to_dict(self):
        return {
            "split_type": self.split_type,
            "account": self.account,
            "name": self.name,
            "memo": self.memo
        }



import unittest
from tests.conftest import *


class TestMember(unittest.TestCase):

    def setUp(self):
        print("setup")

    def tearDown(self):
        print("tearDown")

    def test_create_enterprise(self):
        lic_info = dg_sdk.BussinessLicInfo(reg_name="test",
                                           ent_type="1",
                                           license_code="20200513509363672",
                                           reg_prov_id="350000",
                                           reg_area_id="350200",
                                           reg_district_id="350203",
                                           reg_detail="吉林省长春市思明区解放2路61686340",
                                           license_validity_type="0",
                                           license_begin_date="20200401",
                                           license_end_date="20300101")

        legal_info = dg_sdk.LegalInfo(legal_name="陈立健",
                                      legal_cert_type="00",
                                      legal_cert_no="321084198912066512",
                                      legal_cert_validity_type="1",
                                      legal_cert_begin_date="20121201",
                                      legal_cert_end_date="20301201")
        result = dg_sdk.Member.create_enterprise("test", lic_info, legal_info, "李四", '13144445555')
        assert result["resp_code"] == "00000000"

    def test_create_individual(self):
        result = dg_sdk.Member.create_individual("test",
                                                 "00",
                                                 "301000000009888878",
                                                 "0",
                                                 "20210101",
                                                 '13144445555',
                                                 '20310101')
        assert result["resp_code"] == "00000003"

    def test_modify_individual_base_info(self):
        result = dg_sdk.Member.modify_individual_base_info(contact_email="www123@163.com")
        assert result["resp_code"] == "00000003"

    def test_modify_enter_base_info(self):
        result = dg_sdk.Member.modify_enter_base_info(legal_cert_type="00",
                                                      legal_cert_no="321084198912066512",
                                                      legal_cert_validity_type="1",
                                                      legal_cert_begin_date="20121201",
                                                      legal_cert_end_date="20301201",
                                                      license_validity_type="0",
                                                      license_begin_date="20200401",
                                                      license_end_date="20300101"
                                                      )
        assert result["resp_code"] == "00000003"

    def test_reg_busi_info(self):
        result = dg_sdk.Member.reg_busi_info(upper_huifu_id=upper_huifu_id)
        assert result["resp_code"] == "00000003"

    def test_query_user_detail(self):
        result = dg_sdk.Member.query_user_detail()
        assert result["resp_code"] == "00000003"



from dg_sdk.merchant.module.file_info import FileInfo
from typing import List


class SettlementInfo(object):
    """
    结算信息
    """
    settlement_id = ""
    qualification_type = ""
    activities_id = ""
    file_list = ""
    activities_rate = ""

    def __init__(self, settlement_id, qualification_type, file_list: List[FileInfo], activities_rate="",
                 activities_id=""):
        """
        结算配置信息
        :param settlement_id: 营业执照信息
        :param qualification_type: 法人手机号
        :param activities_id: 是否允许商户使用总部资质
        :param file_list: 文件列表
        :param activities_rate: 行业一级分类
        """

        self.settlement_id = settlement_id
        self.qualification_type = qualification_type
        self.activities_id = activities_id
        self.file_list = file_list
        self.activities_rate = activities_rate

    def obj_to_dict(self):
        result = {
            "qualification_type": self.qualification_type,
            "activities_id": self.activities_id,
            "activities_rate": self.activities_rate,
            "settlement_id": self.settlement_id
        }

        if self.file_list:
            file_info_list = []
            for file in self.file_list:
                file_info_list.append(file.obj_to_dict())
            result["file_list"] = file_info_list

        return result



from dg_sdk.dg_client import DGClient
from dg_sdk.core.rsa_utils import rsa_long_encrypt


class CreditCardInfo(object):
    """
    银行卡分期卡片对象
    """
    bank_card_mobile_no = ""  # 银行卡手机号
    bank_card_no = ""  # 银行卡号
    card_name = ""  # 持卡人姓名
    certificate_no = ""  # 证件号
    certificate_type = ""  # 证件类型
    bank_no = ""  # 银行编号
    card_act_type = ""  # 银行账户类型， E：对公，P：对私
    card_type = ""  # 卡类型，D:借记卡 C:信用卡 P:存折 Y:预付费卡 V:虚拟账户 Z:借贷合一卡
    cvv2 = ""  # cvv2
    valid_date = ""  # 有效期

    def __init__(self, bank_card_mobile_no, bank_card_no, card_name, certificate_no, certificate_type, bank_no="",
                 card_act_type="", card_type="", cvv2="", valid_date=""):
        """
        银行卡分期卡片对象
        :param bank_card_mobile_no: 银行卡手机号
        :param bank_card_no: 银行卡号
        :param card_name: 持卡人姓名
        :param certificate_no: 证件号
        :param certificate_type: 证件类型
        :param bank_no: 银行编号
        :param card_act_type: 银行账户类型， E：对公，P：对私
        :param card_type:  卡类型，D:借记卡 C:信用卡 P:存折 Y:预付费卡 V:虚拟账户 Z:借贷合一卡
        :param cvv2: cvv2
        :param valid_date: 有效期
        """
        self.bank_card_mobile_no = rsa_long_encrypt(bank_card_mobile_no, DGClient.mer_config.public_key)
        self.bank_card_no = rsa_long_encrypt(bank_card_no, DGClient.mer_config.public_key)
        self.certificate_no = rsa_long_encrypt(certificate_no, DGClient.mer_config.public_key)
        self.cvv2 = rsa_long_encrypt(cvv2, DGClient.mer_config.public_key)
        self.valid_date = rsa_long_encrypt(valid_date, DGClient.mer_config.public_key)
        self.card_name = card_name
        self.certificate_type = certificate_type
        self.bank_no = bank_no
        self.card_act_type = card_act_type
        self.card_type = card_type



from dg_sdk.request_tools import request_post
from dg_sdk.pay.pay_api_urls import card_trade_query


class POS(object):
    """
    POS 机交易
    """

    @classmethod
    def query(cls, trans_date, order_type, trade_terminal_device_data, *, out_order_id="", req_seq_id="", **kwargs):
        """
        银行卡交易查询接口
        https://paas.huifu.com/partners/api/#/znapp/zn_term_xt_yhkjyxqcx
        :param trans_date: 交易日期
        :param order_type: 订单类型
        :param trade_terminal_device_data: 交易终端设备数据
        :param out_order_id: 外部交易订单号
        :param req_seq_id: 终端交易订单号
        :param kwargs:  非必填额外参数
        :return: 支付对象
        """

        required_params = {
            "trans_date": trans_date,
            "order_type": order_type,
            "out_order_id": out_order_id,
            "req_seq_id": req_seq_id,
            "trade_terminal_device_data": trade_terminal_device_data,
        }

        required_params.update(kwargs)
        return request_post(card_trade_query, required_params, need_seq_id=False)



# 微信商户配置
config = "/v2/merchant/busi/config"
# 微信商户配置查询
query_config = "/v2/merchant/busi/config/query"
# 微信实名认证
apply_wx_real_name = "/v2/merchant/busi/realname"
# 微信实名认证状态查询
query_apply_wx_real_name = "/v2/merchant/busi/realname/query"
# 微信特约商户进件申请
apply_wx_special_mer_sign = "/ssproxy/direct/applyWxSpecialMerSign"
# 查询微信申请状态
query_wx_special_mer_sign = "/ssproxy/direct/queryWxSpecialMerSign"
# 修改微信结算帐号
modify_wx_settle_info = "/ssproxy/direct/modifyWxSettlementInfo"
# 查询微信结算账户
query_wx_settle_info = "/ssproxy/direct/queryWxSettlementInfo"
# 微信关注配置
wx_subscribe_config = "/ssproxy/direct/wxSubscribeConfig"
# 微信关注配置查询
query_wx_subscribe_config = "/ssproxy/direct/queryWxSubscribeConfig"



from setuptools import setup,find_packages
import io
import re

with io.open('README.rst', 'rt', encoding='utf8') as f:
    readme = f.read()

with io.open('dg_sdk/dg_client.py', 'rt', encoding='utf8') as f:
    version = re.search(r'__version__ = \'(.*?)\'', f.read()).group(1)

setup(
    name='dg_sdk',
    version=version,
    author="huifu developers",
    author_email="yingyong.wang@huifu.com",
    install_requires=['requests>=2.22.0',
                      'pycryptodome>=3.8.2',
                      'Crypto',
                      'chardet',
                      'fishbase==1.5'],
    url='https://paas.huifu.com/',
    description='汇付天下为了提高客户的接入体验，特提供封装的开发SDK，使用本SDK将极大的简化开发者的工作，开发者将无需考虑通信、签名、验签等，只需要关注业务参数的拼装',
    long_description=readme,
    packages=find_packages(),
    classifiers=[
        # How mature is this project? Common values are
        #   3 - Alpha
        #   4 - Beta
        #   5 - Production/Stable
        'Development Status :: 4 - Beta',

        # Indicate who your project is intended for
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ]

)



from dg_sdk.request_tools import request_post
from dg_sdk.dg_client import DGClient
from dg_sdk.merchant.terminal_api_urls import *


class Terminal(object):
    """
    终端设备
    """

    @classmethod
    def add(cls, **kwargs):
        """
        新增终端设备

        https://paas.huifu.com/partners/api/#/zdsb/api_zdbb_xzzd
        :param kwargs: 非必填额外参数
        :return:
        """

        required_params = {
            "product_id": DGClient.mer_config.product_id,
        }
        required_params.update(kwargs)
        return request_post(add_terminal, required_params)

    @classmethod
    def cancel(cls, device_id, **kwargs):
        """
        注销终端设备

        https://paas.huifu.com/partners/api/#/zdsb/api_zdbb_zxzd
        :param device_id: 每页条数
        :param kwargs: 非必填额外参数
        :return:
        """
        required_params = {
            "device_id": device_id
        }
        required_params.update(kwargs)
        return request_post(cancel_terminal, required_params)

    @classmethod
    def query_list(cls, device_id="", page_size="10", page_num="1", **kwargs):
        """
        绑定终端查询

        https://paas.huifu.com/partners/api/#/zdsb/api_zdbb_bdzdxxcx
        :param device_id: 订单号
        :param page_size: 分页条数，最大50，最小1
        :param page_num: 分页页码，不传则默认为第1页
        :param kwargs: 非必填额外参数
        :return:
        """

        required_params = {
            "device_id": device_id,
            "product_id": DGClient.mer_config.product_id,
            "page_size": page_size,
            "page_num": page_num
        }
        required_params.update(kwargs)
        return request_post(query_list, required_params)



import unittest
from tests.conftest import *


class TestHuabei(unittest.TestCase):

    def setUp(self):
        print("setup")

    def tearDown(self):
        print("tearDown")

    def test_create_enterprise(self):
        result = dg_sdk.Huabei.create_pcredit_solution("test",
                                                       start_time="2022-06-01 00:00:00",
                                                       end_time="2023-07-01 00:00:00",
                                                       max_money_limit="200.00",
                                                       amount_budget="100.00",
                                                       install_num_str_list="3",
                                                       budget_warning_money="100",
                                                       budget_warning_mail_list="wwww@123.com",
                                                       min_money_limit="100.00",
                                                       budget_warning_mobile_no_list="13122223333")
        assert result["resp_code"] == "00000001"

    def test_add_ali_cert_info(self):
        file = dg_sdk.FileInfo("F120", "fadsfasdfasdfsdfs", "fileName")
        file2 = dg_sdk.FileInfo("F121", "fadsfasdfasdfsdfs", "fileName")
        file_list = [file, file2]
        result = dg_sdk.Huabei.add_ali_cert_info("test", file_list)
        assert result["resp_code"] == "00000003"

    def test_modify_solution_status(self):
        result = dg_sdk.Huabei.modify_solution_status("test", "2")
        assert result["resp_code"] == "00000001"

    def test_modify_pcredit_solution(self):
        result = dg_sdk.Huabei.modify_pcredit_solution("test",
                                                       solution_id="2fasdf",
                                                       start_time="2022-06-01 00:00:00",
                                                       end_time="2023-07-01 00:00:00")
        assert result["resp_code"] == "00000003"

    def test_query_hb_solution(self):
        result = dg_sdk.Huabei.query_hb_solution(solution_id="2fasdf",
                                                 start_time="2022-06-01 00:00:00",
                                                 end_time="2023-07-01 00:00:00")
        assert result["resp_code"] == "00000001"

    def test_query_hb_activity(self):
        result = dg_sdk.Huabei.query_hb_activity(solution_id="2fasdf")
        assert result["resp_code"] == "00000000"



class BussinessLicInfo(object):
    """
    营业执照信息
    """
    reg_name = ""
    ent_type = ""
    license_code = ""
    license_validity_type = ""
    license_begin_date = ""
    license_end_date = ""
    reg_prov_id = ""
    reg_area_id = ""
    reg_district_id = ""
    reg_detail = ""

    def __init__(self, reg_name, ent_type, license_code, license_validity_type, reg_prov_id, reg_area_id,
                 reg_district_id, reg_detail, license_begin_date, license_end_date=""):
        """
        营业执照信息
        :param reg_name: 商户名称
        :param ent_type: 公司类型，1:政府机构 2:国营企业 3:私营企业 4:外资企业 5:个体工商户 7:事业单位
        :param license_code: 营业执照编号
        :param license_validity_type: 营业执照有效期类型，1:长期有效 0:非长期有效
        :param license_begin_date: 营业执照有效期开始日期yyyyMMdd
        :param license_end_date: 营业执照有效期截止日期
        :param reg_prov_id: 注册省
        :param reg_area_id: 注册市
        :param reg_district_id: 注册区
        :param reg_detail: 注册详细地址
        """

        self.reg_name = reg_name
        self.ent_type = ent_type
        self.license_code = license_code
        self.license_validity_type = license_validity_type
        self.license_begin_date = license_begin_date
        self.license_end_date = license_end_date
        self.reg_prov_id = reg_prov_id
        self.reg_area_id = reg_area_id
        self.reg_district_id = reg_district_id
        self.reg_detail = reg_detail

    def obj_to_dict(self):
        return {
            "reg_name": self.reg_name,
            "ent_type": self.ent_type,
            "license_code": self.license_code,
            "license_validity_type": self.license_validity_type,
            "license_begin_date": self.license_begin_date,
            "license_end_date": self.license_end_date,
            "reg_prov_id": self.reg_prov_id,
            "reg_area_id": self.reg_area_id,
            "reg_district_id": self.reg_district_id,
            "reg_detail": self.reg_detail
        }



class CashConfigInfo(object):
    """
    取现配置
    """
    cash_type = ""
    fix_amt = ""
    fee_rate = ""

    def __init__(self, cash_type="", fix_amt="", fee_rate=""):
        """
        结算配置信息
        :param cash_type: 业务类型D0:当日到账;T1:下个工作日到账;D1:下个自然日到账
        :param fix_amt: 提现手续费（固定/元）开通提现业务时必须填写一种收费方式
        :param fee_rate: 费率（百分比/%）开通提现业务时必须填写一种收费方式
        """

        self.cash_type = cash_type
        self.fix_amt = fix_amt
        self.fee_rate = fee_rate

    def obj_to_dict(self):
        return {
            "cash_type": self.cash_type,
            "fix_amt": self.fix_amt,
            "fee_rate": self.fee_rate
        }



from dg_sdk.dg_client import DGClient
from dg_sdk.core.rsa_utils import rsa_long_encrypt


class Cert(object):
    """
    证件对象
    """
    cert_type = ""  # 证件类型
    cert_id = ""  # 证件ID
    cert_validity_type = ""  # 个人证件有效期类型
    cert_begin_date = ""  # 个人证件有效期起始日
    cert_end_date = ""  # 个人证件有效期到期日，长期有效不填

    def __init__(self, cert_type, cert_id, cert_validity_type, cert_begin_date, cert_end_date=""):
        self.cert_type = cert_type
        self.cert_id = rsa_long_encrypt(cert_id, DGClient.mer_config.public_key)
        self.cert_validity_type = cert_validity_type
        self.cert_begin_date = cert_begin_date
        self.cert_end_date = cert_end_date



import unittest
from tests.conftest import *


class TestScanPayment(unittest.TestCase):

    def setUp(self):
        # dg_sdk.DGClient.mer_config = dg_sdk.MerConfig(private_key, public_key, sys_id, product_id, huifu_id)

        print("setup")

    def tearDown(self):
        print("tearDown")

    def test_payment_create(self):
        result = dg_sdk.ScanPayment.create(trade_type="A_NATIVE",
                                           trans_amt="1.00",
                                           goods_desc="test")
        assert result["resp_code"] == "00000100"

    def test_payment_query(self):
        result = dg_sdk.ScanPayment.create(trade_type="A_NATIVE",
                                           trans_amt="1.00",
                                           goods_desc="test")

        result = dg_sdk.ScanPayment.query(org_req_date=result["req_date"],
                                          org_req_seq_id=result["req_seq_id"])

        assert result["resp_code"] == "00000000"

    def test_payment_close(self):
        result = dg_sdk.ScanPayment.create(trade_type="A_NATIVE",
                                           trans_amt="1.00",
                                           goods_desc="test")

        result = dg_sdk.ScanPayment.close(org_req_date=result["req_date"],
                                          org_req_seq_id=result["req_seq_id"])

        assert result["resp_code"] == "20000001"

    def test_payment_close_query(self):
        result = dg_sdk.ScanPayment.create(trade_type="A_NATIVE",
                                           trans_amt="1.00",
                                           goods_desc="test")
        result = dg_sdk.ScanPayment.close(org_req_date=result["req_date"],
                                          org_req_seq_id=result["req_seq_id"])
        result = dg_sdk.ScanPayment.close_query(org_req_date=result["req_date"],
                                                org_req_seq_id=result["req_seq_id"])

        assert result["resp_code"] == "23000001"

    def test_payment_refund(self):
        result = dg_sdk.ScanPayment.create(trade_type="A_NATIVE",
                                           trans_amt="1.00",
                                           goods_desc="test")

        result = dg_sdk.ScanPayment.refund(ord_amt="0.01",
                                           org_req_date=result["req_date"],
                                           org_req_seq_id=result["req_seq_id"])

        assert result["resp_code"] == "23000000"

    def test_payment_refund_query(self):
        result = dg_sdk.ScanPayment.create(trade_type="A_NATIVE",
                                           trans_amt="1.00",
                                           goods_desc="test")

        result = dg_sdk.ScanPayment.refund(ord_amt="0.01",
                                           org_req_date=result["req_date"],
                                           org_req_seq_id=result["req_seq_id"])
        result = dg_sdk.ScanPayment.refund_query(org_req_date=result["req_date"],
                                                 org_req_seq_id=result["req_seq_id"])

        assert result["resp_code"] == "23000001"

    def test_union_user_id(self):
        result = dg_sdk.ScanPayment.union_user_id("fadsfa/tTBQ==")
        assert result["data"]["resp_code"] == "90000000"

    def test_micro_create(self):
        result = dg_sdk.ScanPayment.micro_create("0.10","test","12212312312312",risk_check_data)
        assert result["resp_code"] == "10000000"

    def test_confirm(self):
        result = dg_sdk.ScanPayment.confirm(org_req_date="20220401",org_req_seq_id="22121212121221")
        assert result["resp_code"] == "23000001"

    def test_confirm_query(self):
        result = dg_sdk.ScanPayment.confirm_query(org_req_date="20220401",org_req_seq_id="22121212121221")
        assert result["resp_code"] == "23000001"

    def test_confirm_refund(self):
        result = dg_sdk.ScanPayment.confirm_refund(org_req_date="20220401",org_req_seq_id="22121212121221")
        assert result["resp_code"] == "23000001"
